function [output_point]=auto_find(struct_id,saveflag)
global app;

%get ext image
%  %create the summed ext image
ext=zeros(app.data.ext.ysize, app.data.ext.xsize);
disp([num2str(app.extspot(struct_id).ExtEndImage-app.extspot(struct_id).ExtStartImage+1) ' images in sum'])
for i=app.extspot(struct_id).ExtStartImage:app.extspot(struct_id).ExtEndImage
  ext = ext + edf_read(sprintf('ext/ext%04d.edf',i));
end
extsummed=ext/(app.extspot(struct_id).EndImage-app.extspot(struct_id).StartImage+1);

%read maximum intensity ext image from full
ext = edf_read(sprintf('full/full%04d.edf',app.extspot(struct_id).MaxImage),app.bb.directbeam);

% make a mask for the extinction image
% use mask_extinction_function, which determines 180 degree (single difspot)
% or 360 degree (pair of difspots) treatment

%ext_mask = mask_extinction_function(struct_id);


%  %get the difspot image, transpose
%  dif = edf_read(sprintf('difspot/difspot%05d.edf',app.extspot(struct_id).ID))';

%read max intensity difspot from full
dif = edf_read(sprintf('full/full%04d.edf',app.extspot(struct_id).MaxImage),app.extspot(struct_id).BoundingBox);


%calc centre of mass, area of difspot
com_x = sum(dif) * ([1:length(sum(dif))]') / sum(sum(dif));
com_y = (sum(dif')*[1:length(sum(dif'))]')/sum(sum(dif'));
area = length(find(dif~=0));


%ext - direct beam image of sample, containing extinction spots
%dif - diffraction spot image

%   %attempt to reduce fringing at top and bottom in s5_dct1_
%   ext=roifill(ext,[1 471 471 1],[1 1 7 7]);
%   ext=roifill(ext,[1 471 471 1],[390 390 400 400]);
%   figure(1); imshow(ext,[]);
%   figure(2); imshow(dif,[]);
%   iptwindowalign(figure(1),'right',figure(2),'left')
%   iptwindowalign(figure(1),'top',figure(2),'top')


%%%%%%%%%%%%%%%%%%%
% Gradient stuff
%%%%%%%%%%%%%%%%%%%

%make dif spot gradient, threshold
dif_med = gtImgMedianFilter2(dif, [5 5]);
[dif_gradx,dif_grady]=gradient(dif_med);

dif_grad = sqrt((dif_gradx).^2+(dif_grady).^2);
grad_thresh = (mean(dif_grad(:))+1*std(dif_grad(:)));
grad_thresh2 = max(dif_grad(:));

dif_gradx_sign = sign(dif_gradx);
dif_gradx_t1=abs(dif_gradx) > grad_thresh;
dif_gradx_t1 = dif_gradx_sign.*dif_gradx_t1;

dif_grady_sign = sign(dif_grady);
dif_grady_t1=abs(dif_grady) > grad_thresh;
dif_grady_t1 = dif_grady_sign.*dif_grady_t1;

%make dif spot perimeter for display - snake input?
dif_spot = dif_med > 0.1*max(dif_med(:));
dif_spot_perimeter=double(bwperim(dif_spot));

%median filter, find edges
ext_med = gtImgMedianFilter2(ext, [9 9]);
ext_edges=edge(ext_med,0.001);

[ext_gradx,ext_grady]=gradient(ext_med);

ext_gradx_sign = -sign(ext_gradx);
ext_gradx = abs(ext_gradx);
ext_gradx_t1=and(ext_gradx>grad_thresh, ext_gradx<grad_thresh2);
ext_gradx_t1 = ext_gradx_sign.*ext_gradx_t1;

ext_grady_sign = -sign(ext_grady);
ext_grady = abs(ext_grady);
ext_grady_t1=and(ext_grady>grad_thresh, ext_grady<grad_thresh2);
ext_grady_t1 = ext_grady_sign.*ext_grady_t1;

%pad dif_grad to size of ext to use correlate
dif_maskx=zeros(size(ext));
dif_maskx(1:size(dif_gradx_t1,1),1:size(dif_gradx_t1,2))=dif_gradx_t1;
dif_masky=zeros(size(ext));
dif_masky(1:size(dif_grady_t1,1),1:size(dif_grady_t1,2))=dif_grady_t1;

dif_perim_mask=zeros(size(ext));
dif_perim_mask(1:size(dif_gradx_t1,1),1:size(dif_gradx_t1,2))=dif_spot_perimeter;
dif_spot_mask=zeros(size(ext));
dif_spot_mask(1:size(dif_gradx_t1,1),1:size(dif_gradx_t1,2))=dif_spot;


if 1
  disp('Using mask to reduce search area')
  extmask=mask_extinction_function(struct_id);
  extmask=extmask(1:end-1,1:end-1);

  ext_gradx_t1(~extmask)=0;
  ext_grady_t1(~extmask)=0;
else
  extmask=ones(2048);
end
% do correlation
cc_x=abs(ifft2(fft2(ext_gradx_t1).*conj(fft2(dif_maskx))));% from correlate.m
cc_y=abs(ifft2(fft2(ext_grady_t1).*conj(fft2(dif_masky))));% from correlate.m

cc= sqrt(cc_x.^2 + cc_y.^2);

[tmp,tmp2] = max(cc(:));
[tmp3,tmp4] = ind2sub(size(cc),tmp2);
shift = [tmp3 tmp4];

%apply shifts
dif_perim_mask=roll(dif_perim_mask,shift(1),shift(2));
dif_spot_mask=roll(dif_spot_mask,shift(1),shift(2));
com_x = com_x + shift(2);
com_y = com_y + shift(1);
output_point = round([com_x com_y]); %where user would click in find_spots...

if 1
  % produce display
if 0
  figure(1)
  imshow(dif,[]);
end
  figure(2)
  % set(2,'visible','off')
  clf
  h1=imshow(ext,[]);
  hold on
  h3=imagesc(cat(3,dif_perim_mask, zeros(size(dif_perim_mask)), zeros(size(dif_perim_mask))));
  set(h3,'alphadata',dif_perim_mask);
  plot(com_x, com_y, 'xr', 'markersize', 10)
  h4=imagesc(cat(3,zeros(size(extmask)),~extmask,zeros(size(extmask))));
  set(h4,'alphadata',0.2)
  hold off
  drawnow
  title(num2str(struct_id))
end
global point
point(struct_id).x=com_x;
point(struct_id).y=com_y;

% save if so requested
if exist('saveflag','var') && saveflag==true
  disp('Saving...')
  fname=sprintf('/data/id19/graintracking/tmp/anotherovernight%04d.jpg',struct_id);
  save('/data/id19/graintracking/tmp/anotherovernight.mat','point')
  print(gcf,'-djpeg',fname)
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%ength(h_ax)==2
disp('Snake code')
im=extsummed;

if 1
  disp('Blurring for snake')
  im=gaussianBlur(im,1);
end
perim=dif_perim_mask;
[fx,fy]=gradient(im);
fmag=sqrt(fx.^2+fy.^2);
ext_snake=-im;  % make the spot white
[y,x]=find(perim);

% gtOPP hangs if there are two contours in 'perimeter'.. FIX!


[x,y]=gtOrderPerimeterPoints(x,y);


[u,v] = GVF(fmag, 0.2, 15);  % 0.2,80
disp(' Normalizing the GVF external force ...');
mag = sqrt(u.^2+v.^2);
pxnorm = u./(mag+1e-10);pynorm = v./(mag+1e-10);
px=u;py=v;

% good for 700
tension=.1;
rigidity=.5;
viscosity=1;  % must be greater than 0.1 or so!
force=1;  % positive if the spot is bright, negative if the spot is dark
iter=5;
% good for ...
%snakeoptions.tension=0.5;
%snakeoptions.rigidity=1;
%snakeoptions.viscosity=1;
%snakeoptions.forcemultiplier=1;
%snakeoptions.iterations=5;

if 0
  figure(3);
  clf
  imagesc(mag,[0 0.08])
  hold on
  quiver(px*100,py*100,'r');
  axis ij
  axis equal
  pad=25;
  axis([min(x(:))-pad max(x(:))+pad min(y(:))-pad max(y(:))+pad])
  h_ax(1)=gca;
end

figure(2)
clf
imagesc(extsummed),axis image,colormap(gray)
axis equal
pad=25;
axis([min(x(:))-pad max(x(:))+pad min(y(:))-pad max(y(:))+pad])
hold on
snakedisp(x,y,'r-')
h_ax(2)=gca;
if h_ax(1)~=0
  linkaxes(h_ax,'xy')
end

[x,y]=snakeinterp(x,y,2,1);
drawnow
clear hp
%forcefield.x=pxnorm;
%forcefield.y=pynorm;
for i=1:10,
%  [x,y]=gtSnakeDeform(x,y,forcefield,snakeoptions);
  [x,y] = snakedeform(x,y,tension,rigidity,viscosity,force,pxnorm,pynorm,iter);
  %  [x,y] = snakeinterp(x,y,5,0.5);
  [x,y]=snakeinterp(x,y,2,1);
  if exist('hp','var')
    delete(hp)
  end
%  hp=snakedisp(x,y,'g.-');
%  title(['Deformation in progress,  iter = ' num2str(i*iter)])
%  drawnow
end
snakedisp(x,y,'g-')

% save if so requested
if exist('saveflag','var') && saveflag==true
  disp('Saving snake...')
  fname=sprintf('/data/id19/graintracking/tmp/snake%04d.jpg',struct_id);
  print(gcf,'-djpeg',fname)
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end


