function im=gtPlaceDifspotinFull(struct_id, parameters, varargin)
% GTPLACEDIFSPOTINFULL  Draws all the difspots together
%     im=gtPlaceDifspotinFull(struct_id, parameters, varargin)
%     --------------------------------------------------------
%     Returns the full image requested, cropped to the specified difspot
%     bounding box
%
%     INPUT:
%        struct_id - grain{grainid}.difspots
%       parameters - parameters.mat
%         varargin - connected (<logical> {0}) *already connected to the database == 1*
%                    save (<logical> {0})      *desire to save the produced image == 1*
%                    replace (<logical> {0})   *replace existing
%                                               <name>_summed.edf file == 1*
%                    draw (<logical> {0})      *show image == 1*
%                    id (<double> {0})         *grain id*
% 
%     OUTPUT:
%        im - image with all the difspots summed
%
%

app.id        = 0;
app.draw      = false;
app.connected = false;
app.save      = false;
app.replace   = false;
app=parse_pv_pairs(app,varargin);


if ~exist('parameters','var') || isempty(parameters)
    parameters=[];
    load('parameters.mat');
end 

name=parameters.acq.name;
namefull=[name '_grain' num2str(app.id) '_summed.edf'];

if exist(namefull,'file')
    if app.replace
        im=edf_read(namefull);
        summed=true;
    else
        summed=false;
    end
else
    summed=false;
end

if ~summed
    im=zeros(parameters.acq.ydet,parameters.acq.xdet);
    
    % connect to database

    if ~app.connected
        gtDBConnect();
        app.connected=true;
    end

    for i=1:length(struct_id)

        %mysqlcmd=['select BoundingBoxXorigin, BoundingBoxYorigin, BoundingBoxXsize, BoundingBoxYsize '...
        %    'from ' name 'difspot where difspotID=' num2str(struct_id(i))];

        %[BoundingBoxXorigin, BoundingBoxYorigin, BoundingBoxXsize, BoundingBoxYsize]=mym(mysqlcmd);
        full=zeros(size(im));
        [dif,bb]=gtGetSummedDifSpot(struct_id(i),parameters,app.connected);
        
        full=gtPlaceSubImage(dif,full,bb(1),bb(2));  %BoundingBoxXorigin, BoundingBoxYorigin);
        im=im+full;
    end
    
end % end if ~summed

if app.draw
    figure();
    imshow(im,[]);
end

% added by LNervo
if app.save && ~summed
    id=app.id;
    edf_write(im,namefull);
end

end  % end of function
