function [dif_maskx, dif_masky] = gtnew_prepare_correlation_image(struct_id, ndx_im, grad_thresh, grad_thresh2)

%prepare image to be subtracted from subsequent correlation inputs
%ie - edge detected image of difspot, placed at extspot location, in the
%relevent ext image, but calculated with threshold values of the new difspot

parameters=[]; 
if isempty(parameters)
  disp('Loading parameter file')
  load('parameters.mat');
end

%read relevent difspot image from full
dif = gtGetDifImage(ndx_im, struct_id);

%calc centre of mass, area of difspot
%this needs to be the whole, summed difspot)
difsummed=gtGetSummedDifSpot(struct_id);
com_x = sum(difsummed) * ((1:length(sum(difsummed)))') / sum(sum(difsummed));
com_y = (sum(difsummed')*(1:length(sum(difsummed')))')/sum(sum(difsummed'));

%make dif spot gradient, threshold
dif_med = gtImgMedianFilter2(dif, [5 5]);
[dif_gradx,dif_grady]=gradient(dif_med);

dif_gradx_sign = sign(dif_gradx);
dif_gradx_t1=abs(dif_gradx) > grad_thresh;
dif_gradx_t1 = dif_gradx_sign.*dif_gradx_t1;

dif_grady_sign = sign(dif_grady);
dif_grady_t1=abs(dif_grady) > grad_thresh;
dif_grady_t1 = dif_grady_sign.*dif_grady_t1;

%search com of difspot in extinction image
%[ext_com_x,ext_com_y] = mym(sprintf('select CentroidX,CentroidY from %sextspot where extspotID=%d',parameters.acq.name,struct_id));
[ext_bb, ext_centroid] = gtGetBBProps(struct_id,'search')
shift_x = ceil(ext_centroid(1) - com_x);
shift_y = ceil(ext_centroid(2) - com_y);

%make ext sized image, paste in dif spot...
dif_maskx=gtPlaceSubImage(dif_gradx_t1,zeros(parameters.acq.bb(4), parameters.acq.bb(3)),1,1);
dif_masky=gtPlaceSubImage(dif_grady_t1,zeros(parameters.acq.bb(4), parameters.acq.bb(3)),1,1);

%roll mask to correct position
dif_maskx=roll(dif_maskx,shift_y,shift_x);
dif_masky=roll(dif_masky,shift_y,shift_x);

