% MASK_EXTINCTION.M
% Given a full Frelon image, with the user selection of a diffraction spot,
% attempts to mask the possible area in the extinction image within which
% the spot could have diffracted from.  See below for assumptions about
% diffraction criteria.
%
% Based on plot_rings.m by Andy King
%
% Greg Johnson September 2006

%modified to at as a function, returning mask based on input of difspot
%struct_id
%Andy, 11/9/2006


function mask_ext = mask_extinction_function(struct_id);

global app;

disp('HARD CODED variables here')
% produces oversize image
% image size 2048*2048!');
im=zeros(2048);

bb=app.bb.directbeam;

dif_bb(1,:) = app.extspot(struct_id).BoundingBox;
dif_cent(1,:) = app.extspot(struct_id).Centroid;





flag = 0; %180, one difspot, default case
if isfield(app.extspot(struct_id),'pair_id')
  if ~isempty(app.extspot(struct_id).pair_id) 
    flag = 1;% 360, two difspots, special case
    pair_id = app.extspot(struct_id).pair_id;
    dif_bb(2,:) = app.extspot(pair_id).BoundingBox;%or however...
    dif_cent(2,:) = app.extspot(pair_id).Centroid;
%so dif_bb has two enteries if available
  end
end

if flag == 1%360 degree, two difspots
    

%apply mirror transform to pair position
%disp('HARD CODED center of rotation!');
dif_cent(2,1) = 2048 - dif_cent(2,1);
dif_bb(2,1) = 2048 - dif_bb(2,1) - dif_bb(2,3);

grad = (dif_cent(2,2)-dif_cent(1,2))/(dif_cent(2,1)-dif_cent(1,1));

%in line equation, find all possible c in y=mx+c
%max and min c values gives edges of mask area

c(1) = dif_bb(1,2) - grad*dif_bb(1,1);
c(2) = dif_bb(1,2) - grad*(dif_bb(1,1)+dif_bb(1,3));
c(3) = (dif_bb(1,2)+dif_bb(1,4)) - grad*dif_bb(1,1);
c(4) = (dif_bb(1,2)+dif_bb(1,4)) - grad*(dif_bb(1,1)+dif_bb(1,3));
c(5) = dif_bb(2,2) - grad*dif_bb(2,1);
c(6) = dif_bb(2,2) - grad*(dif_bb(2,1)+dif_bb(2,3));
c(7) = (dif_bb(2,2)+dif_bb(2,4)) - grad*dif_bb(2,1);
c(8) = (dif_bb(2,2)+dif_bb(2,4)) - grad*(dif_bb(2,1)+dif_bb(2,3));
c_min = min(c);
c_max = max(c);

mask_line=zeros(size(im));
y(1) = (grad*1)+c_min;
y(2) = (grad*size(im,1))+c_min;
y(3) = (grad*size(im,1))+c_max;
y(4) = (grad*1)+c_max;

y(find(y<1))=1;
y(find(y>size(im,2)))=size(im,2);
x(1:2) = (y(1:2) - c_min)./grad;
x(3:4) = (y(3:4) - c_max)./grad;

mask(3,:,:) = poly2mask(x,y,size(im,2),size(im,1));

end %line mask for two difspots


for i=1:size(dif_bb,1);%for - to run this for both spots if available%180 degree, single difspot case
  
%centre of difspot - use centre of bb
%dif_bb = app.extspot(struct_id).BoundingBox;
point.x = ceil(dif_bb(i,1)+dif_bb(i,3)/2);
point.y = ceil(dif_bb(i,2)+dif_bb(i,4)/2);


%note - sample width overestimates
%disp('HARD CODED sample width 830-1200 not app.bb!');
xc=app.dist;  
%sample_width=app.bb.directbeam(3);
sample_width=1200-830;

%disp('HARD CODED Al data - a=4.05, FCC!');
tmp=calculate_twotheta(4.05,'FCC',app.energy);
tmp=tmp.elements;
for n=1:length(tmp)
  twotheta(n)=tmp{n}.centre;
end

dist_rear=xc+(sample_width*app.pixelsize/2); % assume sample is cuboid
dist_front=xc-(sample_width*app.pixelsize/2);

rad_front=dist_front*tan(deg2rad(twotheta))/app.pixelsize;
rad_rear=dist_rear*tan(deg2rad(twotheta))/app.pixelsize;

%add a constant to radii based on the size of the difspot
dif_rad = (sqrt(dif_bb(i,3:4)*dif_bb(i,3:4)'))/2;
rad_front = rad_front-dif_rad;
rad_rear = rad_rear+dif_rad;


tmask=zeros(size(im));
for n=1:length(rad_front)
 [xf{n},yf{n}]=circlepoints(point.x,point.y,rad_front(n),40);
 tmp_maskf=poly2mask(xf{n},yf{n},size(im,2),size(im,1));
 [xr{n},yr{n}]=circlepoints(point.x,point.y,rad_rear(n),40);
 tmp_maskr=poly2mask(xr{n},yr{n},size(im,2),size(im,1));
 tmask=tmask | xor(tmp_maskr,tmp_maskf);
end
 
mask(i,:,:)=zeros(size(im));
mask(i,tmask)=1;
  
end%180 case for one or two difspots


%crop mask(s) to size of extinction image
mask_ext=mask(:,bb(2):bb(2)+bb(4),bb(1):bb(1)+bb(3));

if flag == 1
%final mask is the AND of all three masks
mask_ext(1,:,:) = (mask_ext(1,:,:) & mask_ext(2,:,:) & mask_ext(3,:,:));
end

%flatten mask to 2d
mask_ext = reshape(mask_ext(1,:,:), size(mask_ext,2), size(mask_ext,3)); 


