function labgeo = gtMatchRecalculateLabgeo(newvars,newvarsind,oldvars,...
                  labgeobase)

% Recalculates labgeo parameters based on new and old values relative to
% labgeobase. New values come from the user or from fitting.
%
% List of parameters in oldvars: 
%
% 1  = 'Position X';
% 2  = 'Position Y';
% 3  = 'Position Z';
% 4  = 'Tilt in plane';
% 5  = 'Angle U-V';
% 6  = 'Tilt around U';
% 7  = 'Tilt around V';
% 8  = 'Pixel size mean';
% 9  = 'Pixel size ratio';
% 10 = 'lengtha';
% 12 = 'lengthb';
% 13 = 'lengthc';
% 14 = 'alpha';
% 15 = 'beta';
% 16 = 'gamma';



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Detector position, pixel sizes, tilts 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

actvars = oldvars;
actvars(newvarsind) = newvars;

% Detector position
labgeo.detrefpos  = actvars(1:3);

% Pixel sizes
labgeo.pixelsizeu     = actvars(8)*sqrt(actvars(9));
labgeo.pixelsizev     = actvars(8)/sqrt(actvars(9));

% Tilt in plane (increment U vector appr. along V)
detdiru = labgeobase.detdiru + cross(labgeobase.detnorm,...
                               labgeobase.detdiru)*actvars(4);

% Tilt around V - right handed rotation
detdiru = detdiru - labgeobase.detnorm*actvars(6);
detdiru = detdiru/sqrt(detdiru*detdiru');
labgeo.detdiru = detdiru;

% Tilt around U - right handed rotation
detdirv = labgeobase.detdirv + labgeobase.detnorm*actvars(7);
detdirv = detdirv/sqrt(detdirv*detdirv');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Recalculate V according to angle between U and V 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Actual U-V angle
actangle = acosd(detdiru*detdirv');

% Difference vector normalised
diffvec = detdirv - detdiru;
diffvec = diffvec/sqrt(diffvec*diffvec');

% Correction vector along diffvec
corrvec = diffvec*sind(actvars(5)-actangle)/...
          cosd(actvars(5)-actangle/2);

% Apply correction
detdirv = detdirv + corrvec;

% Renormalise V vector
labgeo.detdirv = detdirv/sqrt(detdirv*detdirv');

% Recalculate angle for checking (should be = actvars(5))
%labgeo.uvangle = acosd(labgeo.detdiru*labgeo.detdirv');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Update other 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Update detector normal
detnorm = cross(labgeo.detdiru, labgeo.detdirv);
labgeo.detnorm = detnorm/sqrt(detnorm*detnorm');

% Update detector origin: pixel (0,0) coordinates in LAB ref.
labgeo.detorig = labgeo.detrefpos - ...
    labgeo.detdiru*labgeobase.detrefu*labgeo.pixelsizeu - ...
    labgeo.detdirv*labgeobase.detrefv*labgeo.pixelsizev;


