function hkil = gtCart2Hex(hkl)
% GTCART2HEX  Convert a plane normal in cartesian coordinates (hkl) 
%     hkil = gtCart2Hex(hkl)
%     ----------------------
%     INPUT:
%       hkl  = plane normal indexes
%
%     OUTPUT:
%       hkil = cartesian coordinates for hexagonal materials
%
%     Version 002 25-11-2011 by LNervo
%       *** update version ***
%
%     Version 001 June-2008 by AKing
%       Four index hexagonal coordinatesa are given
%       reverse of the formulae implemented by Sabine in gtForwardSimulate_360
%       the output {hkil} is not normalised in any way.


load('parameters.mat')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% cart to hex
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
hkil=zeros(size(hkl,1), 4);

%change to hexagonal axes
hkil(:,1) = hkl(:,1) - (hkl(:,2)/sqrt(3));
hkil(:,2) = hkl(:,2)*2/sqrt(3);
hkil(:,3) = -(hkil(:,1)+hkil(:,2));
hkil(:,4) = hkl(:,3);

%allow for unit cell parameters
hkil(:,1:3) = hkil(:,1:3)*(parameters.cryst.latticepar(1)*sqrt(3))/2;
hkil(:,4)   = hkil(:,4)*parameters.cryst.latticepar(3);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% hex to orthogonal    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% i=1
% hkil=[1 1 -2 1]
% 
% for i=1:8
% hkl(i,1)= hkil(i,1) + 0.5 * hkil(i,2);
% hkl(i,2)= 3^0.5/2 *hkil(i,2);
% hkl(i,3)= hkil(i,4);
% 
% hkl(i,1)=hkl(i,1)*2/(sqrt(3)*parameters.cryst.latticepar(1));
% hkl(i,2)=hkl(i,2)*2/(sqrt(3)*parameters.cryst.latticepar(1));
% hkl(i,3)=hkl(i,3)/parameters.cryst.latticepar(3);
% 
% %normalise
% tmp = sqrt(sum((hkl.*hkl),2));
% hkl = hkl./(repmat(tmp,1,3))
% end

end % end function
