function gtShowFsim(grain, phaseid, clims)
    
    if ~exist('phaseid', 'var')
        phaseid = 1;
    end
    
    if isnumeric(grain)
        filename = sprintf('4_grains/phase_%02d/grain_%04d.mat',phaseid,grain);
        grain=load(filename);
    end
    
    if (~exist('clims', 'var'))
        clims = 0;
    end

    %leg = { 'flag = 1 : No intensity in raw images', ...
    %        'flag = 2 : Found some intensity in raw images', ...
    %        'flag = 3 : Found segmented intensity - not matching search criteria', ...
    %        'flag = 4 : Found difspot matching search criteria', ...
    %        'flag = 5 : Difspot (pair) identified by indexter' };
    
    leg = { '1: No intensity in raw images', ...
            '2: Intensity in raw images', ...
            sprintf('3: Segmented intensity not\n    matching search criteria'), ...
            '4: Difspot matching search criteria', ...
            '5: Indexed difspot as Friedel pair' };
    
    clims = gtSetColourLimits(grain.full, clims);

    ondet = grain.ondet;
    
    grainid = grain.id;
    
    
    phaseid = grain.phaseid;
    f = figure('Units','normalized','Position',[0 0 0.8 1]);
    %set(f,);
    ax = axes('Parent', f);
    
    colormap(ax, gray);
    imagesc(grain.full, 'Parent', ax, clims);
    axis(ax, 'equal');
    axis(ax, [1 size(grain.full,2) 1 size(grain.full,1)])
    
    gtBrightnessContrast(ax);
    hold(ax, 'on');
    title(sprintf('Phase %d - Grain %d', phaseid, grainid));
    % flag = 1  no intensity in raw images...!
    ind    = find(grain.flag == 1);
    u_vec  = grain.allblobs.uv(ondet(ind),1);
    v_vec  = grain.allblobs.uv(ondet(ind),2);
    if ~isempty(ind) 
        h(1) = plot(u_vec,v_vec,'rx'); 
    else
        h(1) = plot(1, -10 ,'rx');
    end
    
    % flag = 2 some segmented intensity found at predicted spot position
    ind    = find(grain.flag == 2);
    u_vec  = grain.allblobs.uv(ondet(ind),1);
    v_vec  = grain.allblobs.uv(ondet(ind),2);
    if ~isempty(ind) 
        h(2)   = plot(u_vec,v_vec,'mo'); 
    else
        h(2)   = plot(1, -10,'mo');
    end
    
    % flag = 3 some segmented intensity found at predicted spot position
    ind    = find(grain.flag == 3);
    u_vec  = grain.allblobs.uv(ondet(ind),1);
    v_vec  = grain.allblobs.uv(ondet(ind),2);
    if ~isempty(ind) 
        h(3)   = plot(u_vec,v_vec,'bo'); 
    else
        h(3)   = plot(1, -10, 'bo');
    end
    
    % flag = 4  new valid spot collected during forward simulation
    ind    = find(grain.flag == 4);
    u_vec  = grain.allblobs.uv(ondet(ind),1);
    v_vec  = grain.allblobs.uv(ondet(ind),2);
    if ~isempty(ind) 
        h(4)   = plot(u_vec,v_vec,'gd');
    else
        h(4)   = plot(1, -10, 'gd');
    end
    
    % flag = 5  spot has been identified by INDEXTER
    ind    = find(grain.flag == 5);
    u_vec  = grain.allblobs.uv(ondet(ind),1);
    v_vec  = grain.allblobs.uv(ondet(ind),2);
    if ~isempty(ind)
        h(5)   = plot(u_vec,v_vec,'gh');
    else
        h(5)   = plot(1, -10, 'gh');
    end

    % flag = 0  no spot search - just show expected positions
    ind = find(grain.flag == 0);
    if length(ind == length(grain.flag))
        u_vec  = grain.allblobs.uv(ondet(ind),1);
        v_vec  = grain.allblobs.uv(ondet(ind),2);
        h = plot(u_vec,v_vec,'bo'); 
        leg = 'expected spot positions';
    end
    
    %legend(h, leg, 'Location', 'NorthOutside')
    hl = legend(h, leg, 'Location', 'EastOutside');
    

    % Position figure, axes and legend
    set(f,'Units','normalized')
    set(f,'Position',[0 0 0.8 1])

    set(hl,'Units','normalized')
    pos = get(hl,'Position');
    set(hl,'Position',[0.99-pos(3) pos(2) pos(3) pos(4)])
   
    set(ax,'Units','normalized')
    pos = get(ax,'Position');
    set(ax,'Position',[pos(1) 0.05 pos(3) 0.9])
    
    set(f,'Units','normalized')
    set(f,'Position',[0 0 0.8 1])
   
end
