function [stack,stackbw,stackfakes]=gtWriteDifStack3D(grain,parameters)
% write .sdt projection files for ART reconstruction
% 


fake_spots=0;

grainid=grain.id;

grainname=sprintf('grain%d_',grainid);
graindir=sprintf('%s/4_grains/%s',parameters.acq.dir,grainname);
if ~exist(graindir,'dir')
  mkdir(graindir);
end

avgint=grain.stat.intmean;
num_spots=length(grain.difspots);
%num_pairs=length(grain.pairid);


  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


disp('we still suppose looking into the beam - diffraction spots will be flipped !');
vsizemax=0;
hsizemax=0;

se2=strel('disk',2); % used in section fake-spots....
se=strel('disk',6);  % idem

for n=1:num_spots

  % read, zeropad, filter and flip first difspot
  
  dif=gtGetSummedDifSpot(grain.difspots(n),parameters,'connected',1);
  psize(n,:)=size(dif);
  vsizemax=max(psize(n,1),vsizemax);
  hsizemax=max(psize(n,2),hsizemax);
  
  dif=wiener2(dif,[10 10]);
  dif=fliplr(dif);
  % threshold spot for binary reconstruction
  t=graythresh(dif/1000);
  difbw=im2bw(dif/1000,0.15*t);  %changed from 0.15 to 0.25
  dif=avgint*dif/sum(dif(:));
  proj{n}=dif;
  projbw{n}=difbw;
  
  % write out zero padded spots
  tmp=zeros(psize(n,1)+200,psize(n,2)+200);
  dif=gtPlaceSubImage(dif,tmp,101,101);
  difbw=gtPlaceSubImage(difbw,tmp,101,101);
  fname=sprintf('%s/difspot%d',graindir,n);
  sdt_write(fname,dif,'float32');
  fname=sprintf('%s/difbw%d',graindir,n);
  sdt_write(fname,difbw,'float32');
  
  %%  try to approximate the intensity distribution in the spots by that of a sphere...
  
  if fake_spots
	  
	  [vs,hs]=size(proj{n});
	  % try to get a better approximation of contour of the spot using the
	  % matlab canny edge filter
	  mask=imerode(difbw,se);  %  remove gradients in difspot under this mask
	  mask2=imdilate(mask,se2);       %   only will retain edges outside this area
	  ind2=find(mask2>0);
	  ind=find(mask>0);

	  toto=dif;
	  toto(ind)=1;                      % set spot interior to constant intensity

	  edges=edge(toto,'canny',0.1,1.5); % calculate edges
	  edges(ind2)=0;                    % remove inner edge
	  filled=imfill(edges,'holes');
	  opened=imopen(filled,se2);        % will remove spots for which edges were not closed...

	  dist=bwdist(~opened);             % distance transfrom will be used for creation of a sphere-like intensity distribution
	  
	  R=max(dist(:));  
	  
	  fake=2*sqrt(2*R*dist-dist.^2);    % assume ~spherical shape of spot... 
	  fakes{n}=gtCrop(fake,[101,101,hs,vs]);
	  M(n)=gtImgMeanValue(fake);
	  
	  fname=sprintf('%s/fakespot%d',graindir,n);
      sdt_write(fname,fake,'float32');
	  
	end  % if fake_spots

end  

stack=zeros(vsizemax,hsizemax,1,num_spots);
stackbw=zeros(vsizemax,hsizemax,1,num_spots);
stackfakes=zeros(vsizemax,hsizemax,1,num_spots);
% for convenient display of the stack with the help of "montage", we create
% a 4D stack of our cell aray

for n=1:num_spots
  tmp=zeros(vsizemax,hsizemax);
  hstart=floor((hsizemax-psize(n,2))/2+1);
  vstart=floor((vsizemax-psize(n,1))/2+1);
  stack(:,:,1,n)=gtPlaceSubImage(proj{n},tmp,hstart,vstart);
  stackbw(:,:,1,n)=gtPlaceSubImage(projbw{n},tmp,hstart,vstart);
  if fake_spots
    stackfakes(:,:,1,n)=gtPlaceSubImage(fakes{n},tmp,hstart,vstart);
  end
end  


