
function gt_select_projections_auto(grainid, varargin)
  %function gt_select_projections_auto(grainid, varargin)
  %varargin - flag to display figures - default true


  plotflag=1;
  if ~isempty(varargin)
    plotflag=varargin{1};
  end

  filename=sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid);
  tmp=load(filename);

  if isfield(tmp, 'bad') && tmp.bad>=1
    disp('grain already marked as bad')
    return
  end




  %read stack from mat file
  stack=tmp.stack;
  zcenter=tmp.zcenter;
  Omega=tmp.Omega;

  [a,b,c]=size(stack);

  %plot the backpro of this grain
  if plotflag
    figure
    [im]=gtBackproGrain(grainid,zcenter);
    imshow(im,[])
  end

  %get the sinogram and derived data
  sino=stack(zcenter,:,:);
  sino=reshape(sino,b,c);
  binsino=sino>0.1*max(sino(:));
  sino_centers=[];
  sino_widths=[];

  for i=1:size(sino,2)

    %greyscale center
    sino_centers(i)=(sino(:,i)'*[1:length(sino)]')/sum(sino(:,i));

    %width from the thresholded sino
    if max(binsino(:,i))~=0
      dummy=find(binsino(:,i));
      sino_widths(i)=max(dummy)-min(dummy);
      sino_edge1(i)=min(dummy);
      sino_edge2(i)=max(dummy);
    else %case where no intensity in sinogram
      sino_widths(i)=NaN;
      sino_edge1(i)=NaN;
      sino_edge2(i)=NaN;

    end

  end


  %plot the sinogram data - this wil be used to try and select bad
  %projections

  if plotflag
    figure
    plot(Omega,sino_centers,'xr')
    hold on
    plot(Omega,sino_widths,'xb')
    plot(Omega,sino_edge1,'xg')
    plot(Omega,sino_edge2,'xk')

  end

  %fit sine function to the plots
  %fist guess: x0=[A, B, C]
  %options=optimset('lsqcurvefit');
  options=optimset('MaxFunEvals',200);


  bad_initially = find(isnan(sino_centers)); %take these out straight away
  bad_initially = [bad_initially find(isnan(sino_widths))]; %take these out straight away

  dummy=find(~isnan(sino_centers) & ~isnan(sino_widths) & ~isnan(sino_edge1) & ~isnan(sino_edge2)); %don't use bad ones
  Omzero=Omega(find(sino_centers==max(sino_centers)));
  Omzero=(Omzero*pi/180)+pi/2;
  x0=[std(sino_centers(dummy)), Omzero, mean(sino_centers(dummy))];
  [x_centers,a,residuals_centers] = lsqcurvefit(@sfSinoFunction, x0, Omega(dummy), sino_centers(dummy));

  %dummy=find(~isnan(sino_widths)); %don't use bad ones
  Omzero=Omega(find(sino_widths==max(sino_widths)));
  Omzero=(Omzero*pi/180)+pi/2;
  x0=[std(sino_widths(dummy)), 0, mean(sino_widths(dummy))];
  [x_widths,a,residuals_widths] = lsqcurvefit(@sfSinoFunction, x0, Omega(dummy), sino_widths(dummy));

  %dummy=find(~isnan(sino_edge1)); %don't use bad ones
  Omzero=Omega(find(sino_edge1==max(sino_edge1)));
  Omzero=(Omzero*pi/180)+pi/2;
  x0=[std(sino_edge1(dummy)), 0, mean(sino_edge1(dummy))];
  [x_edge1,a,residuals_edge1] = lsqcurvefit(@sfSinoFunction, x0, Omega(dummy), sino_edge1(dummy));

  %dummy=find(~isnan(sino_edge2)); %don't use bad ones
  Omzero=Omega(find(sino_edge2==max(sino_edge2)));
  Omzero=(Omzero*pi/180)+pi/2;
  x0=[std(sino_edge2(dummy)), 0, mean(sino_edge2(dummy))];
  [x_edge2,a,residuals_edge2] = lsqcurvefit(@sfSinoFunction, x0, Omega(dummy), sino_edge2(dummy));



  if plotflag
    x1=1:360;
    %x1=-x1;
    y1 = sfSinoFunction(x_centers,x1);
    plot(x1,y1, 'r-')
    y1 = sfSinoFunction(x_widths,x1);
    plot(x1,y1, 'b-')
    y1 = sfSinoFunction(x_edge1,x1);
    plot(x1,y1, 'g-')
    y1 = sfSinoFunction(x_edge2,x1);
    plot(x1,y1, 'k-')
  end

  %use the residuals to select bad projections (2*std dev test)
  if length(Omega)>50
    range=0.8
  elseif length(Omega)>30
    range=1.2
  else
    range=1.7;
  end


  bad_centers = dummy(find(abs(residuals_centers)>range*std(residuals_centers)));
  bad_widths = dummy(find(abs(residuals_widths)>range*std(residuals_widths)));

  bad_edge1 = dummy(find(abs(residuals_edge1)>range*std(residuals_edge1)));
  bad_edge2 = dummy(find(abs(residuals_edge2)>range*std(residuals_edge2)));





  index=ones(size(Omega));

  index(bad_initially)=0;
  index(bad_centers)=0;
  index(bad_widths)=0;
  index(bad_edge1)=0;
  index(bad_edge2)=0;
  
  %avoid problem where almost all projections are excluded
  if length(find(index))/length(index)<0.7
    disp('select projections auto not happy - ignoring results - no changes')
    disp(sprintf('would use only %0.2f of projections', length(find(index))/length(index)))
    %reset index to ones, ignore automatic result
    return
  end

  if 1
    %save this index of spots to use into the .mat file
    save(filename, 'index', '-append');
  else
    disp('not saving changes!')
  end

end

%sinogram function
function predicted_data=sfSinoFunction(x, Omega)
  %function y = A*sin(omega+B) + C
  predicted_data = (x(1)*sin((Omega*pi/180)+x(2))) + x(3);
end




