function missing = gtFsimCheckMissingGrains(phase_num)
% GTFSIMCHECKMISSINGGRAINS  
%     missing = gtFsimCheckMissingGrains(phase_num)
%     ---------------------------------------------
%     INPUT:
%       phase_num = number of the phase
%
%     OUTPUT:
%       missing = structure with:
%                 ind        = grainid of missing grain from
%                              ForwardSimulation
%                 is_grain   = for each grain true if grain_[id].mat
%                              exists
%                 is_grain_r = is_grain reshaped as 
%                              [nof_grain_per_job,njobs]

% get number of jobs for that functions from OAR
arrays=logviewOar('gtForwardSimulate_v2',[],false);
% if ~isempty(arrays.fname)
%     if ~isempty(arrays.('gtForwardSimulate_v2').logs)
%        filename = arrays.('gtForwardSimulate_v2').logs;
%        [~,njobs] = unix(['grep "njobs" ' filename ' | awk -F" = " ''{print $2}''']);
%       nof_jobs = str2double(njobs);
%     end
% else
    nof_jobs = 1;

% end

% get last gtForwardSimulate_v2 run date from oar.log file
o=fileread('oar.log');
o2=textscan(o,'%s %s %d %s %s');
datemax=max(datenum(o2{4}(:)));

count=[];
list_grains=dir(fullfile( '4_grains',['phase_' sprintf('%02d',phase_num)],'grain_*.mat'));
for i=1:length(list_grains)
    num = str2double(list_grains(i).name(7:10));
    if datenum(list_grains(i).date,'dd-mmm-yyyy')>=datemax
        count(num) = true; 
    else
        count(num) = false;
    end
end


grain=load(fullfile( '4_grains',['phase_' sprintf('%02d',phase_num)],'index.mat' ),'grain');
grain=grain.grain;

% total number of grains
nof_grains = length(grain);

% is_grain contains true if grain_#.mat exists, false if doesn't exist
is_grain=[];
for i=1:nof_grains
    if exist(fullfile( '4_grains',['phase_' sprintf('%02d',phase_num)],['grain_' sprintf('%04d.mat',i)] ),'file')
        if count(i)
            is_grain(i) = true;
        else
            disp(['grain # ' num2str(i) ' may not be updated'])
            is_grain(i) = false;
        end
    else
        is_grain(i) = false;
    end
end

% grains per each job
grains = ceil(nof_grains/nof_jobs);

% fill with NaN to have exact division of nof_grains by nof_jobs
tot_n = nof_jobs * grains;
is_grain(nof_grains+1:tot_n)=NaN;

% grain number of missing files
ind=find(is_grain==0);

% reshape is_grain to have in each column each job status
% column  = job number, row = grain number for that job
is_grain_r = reshape(is_grain,tot_n/nof_jobs,nof_jobs);

missing.ind = ind;
missing.is_grain = is_grain;
missing.is_grain_r = is_grain_r;


clear grain

end % end of function

