function gtSetupForwardSimulation
% simple helper function to run gtForwardSimulate
% whatever the current version is ;-)


parameters = [];
load('parameters.mat');
gtDBConnect();

check=inputwdefault('Do you want to recompile the function ''gtForwardSimulate_v2''? [y/n]','n');
if strcmpi(check,'y')
    gt_mcc('gtForwardSimulate_v2');
end
    
nof_phases = length(parameters.cryst);

if nof_phases > 1
    phaseID = inputwdefaultnumeric('Enter phaseID', num2str(1));   
else
    phaseID = 1;
end

phaseID_str = sprintf('%02d',phaseID);

disp(['Setting up Forward Simulation for phase ' phaseID_str ' ' parameters.cryst(phaseID).name]);
filetable = sprintf('%s_filetable', parameters.acq.name);
% get the latest version of indexter output
grain = [];

for ii = 1 : nof_phases
    filename = fullfile(parameters.acq.dir, '4_grains', sprintf('phase_%02d', ii), 'index.mat');
    load(filename, 'grain');
    % how many grains in this dataset?
    ngrains(ii) = length(grain);
end    


%create / reset sample.mat spot2grain.mat
filename = fullfile(parameters.acq.dir, '4_grains', 'sample.mat');
if exist(filename, 'file') && (nof_phases > 1)
    sample = GtSample.loadFromFile(filename);     % do not create from scratch - we want to keep information related to other phases
else
    sample = GtSample(nof_phases);
    sample.fileTable = sprintf('%s_filetable',parameters.acq.name);
    for ii = 1 : nof_phases
        phase = GtPhase(parameters.cryst(ii).name, ngrains(ii));
        sample.phases{ii} = phase;
    end
    save(filename, 'sample');
end


disp(['Reset phase number ' num2str(phaseID) ' in the sample.mat:'])
disp(['Name : ' parameters.cryst(phaseID).name])
disp(['nof_grains: ' num2str(ngrains(phaseID))])


filename    = fullfile(parameters.acq.dir,'4_grains','spot2grain.mat');
difspot_num  = mym(sprintf('select count(*) from %sdifspot', parameters.acq.name));

if exist(filename, 'file') && nof_phases>1 
    check = inputwdefault('Do you want to reset spot2grain? [y/n]', 'n');
    if ~strcmpi(check, 'y')
        spot2grain  = cell(difspot_num, 1); % cell array linking difspots with grainids
        spot2phase  = cell(difspot_num, 1);
    end
end

% get reconstruction parameters
check = inputwdefault('Use default parameters? [y/n]', 'y');
if ~strcmpi(check, 'y')
    list = build_list_v2();
    parameters.fsim = gtModifyStructure(parameters.fsim, list.fsim(:, 1:2));
    save([parameters.acq.dir '/parameters.mat'],'parameters');
end

% launch forward simulation process to OAR - split to two jobs
check=inputwdefault('Launch Forward Simulation with OAR? [y/n]', 'y');
if strcmpi(check, 'y')
    disp('Launching several separate OAR jobs')
    
    oar.njobs    = min(ceil(ngrains(phaseID)/20), 30); % max 30 jobs
    oar.walltime = ngrains(phaseID) / oar.njobs * 5;  % allow 5 minutes per grain
    
    OARtmp   = ceil(oar.walltime); % total minutes (could be > 60)
    OARm     = mod(OARtmp, 60); % minutes
    OARh     = (OARtmp - OARm) / 60; % hours
    
    OAR_parameters.walltime = sprintf('%02d:%02d:00', OARh, OARm);
    OAR_parameters.njobs = oar.njobs;
    OAR_list{1,1}='njobs'; OAR_list{1,2}='How many OAR jobs?';
    OAR_list{2,1}='walltime'; OAR_list{2,2}='Walltime for OAR jobs (hh:mm:ss)'; 
    
    OAR_parameters=gtModifyStructure(OAR_parameters, OAR_list, 'Parameters for OAR');
    

    OAR_make('gtForwardSimulate_v2', 1, ngrains(phaseID), OAR_parameters.njobs, ...
        [parameters.acq.dir ' ' num2str(phaseID)], true, ...
        'walltime', OAR_parameters.walltime);
    
else
    gtForwardSimulate_v2(1, ngrains(phaseID), pwd, phaseID);
end

end % end of function

