function sample = gtUpdateGrainsConflicts(save_flag)
% GTUPDATEGRAINSCONFLICTS
%     sample = gtUpdateGrainsConflicts(save_flag)
%     -------------------------------------------
%     Loads ./4_grains/sample.mat 
%     Reads ./4_grains/grains_merge.mat
%     Updates ./4_grains/sample.mat
%
%     Updates info from grains_merge.mat:
%       sample.phases{:}.summary{:}
%       sample.phases{:}.conflicts{:}
%       sample.phases{:}.hasConflicts(:)
%       sample.phases{:}.nofConflicts(:)
%
%     INPUT: 
%       save_flag = flag to save 4_grains/sample.mat <logical> {true}
%
%     OUTPUT:
%       sample = updated sample.mat <struct>


if ~exist('save_flag','var') || isempty(save_flag)
    save_flag = true;
end

grains_merge = [];
sample = [];

filedir = fullfile('4_grains');
load(fullfile(filedir,'grains_merge.mat'));
filename = fullfile(filedir,'sample.mat');
load(filename);

for phaseid = 1 : length(sample.phases)
    
    phase = sample.phases{phaseid};
    merge = grains_merge{phaseid};
        
    for grainid = 1 : length(phase.grains)
        fprintf('\b\b\b\b\b\b\b\b\b')
        phase.setTotSpots(grainid, merge.summary{grainid}.totspots);
        phase.setNumGrain(grainid, merge.summary{grainid}.numgrain);
        phase.setIdConflict(grainid, merge.summary{grainid}.idconflict);
        phase.setDelete(grainid, merge.summary{grainid}.delete);
        phase.setFlag(grainid, merge.summary{grainid}.flag);
        phase.setIdSpot(grainid, merge.summary{grainid}.idspot);

        if merge.summary{grainid}.numgrain > 1
            phase.conflicts{grainid} = repmat(GtConflict(), phase.getNumGrain(grainid), 1);
        end
        
        for conflictid = 1 : phase.getNumGrain(grainid)
            phase.setDifspots(grainid, conflictid, merge.conflicts{grainid}(conflictid).difspots);
            phase.setMaxNum(grainid, conflictid, merge.conflicts{grainid}(conflictid).maxnum);
            phase.setMerge(grainid, conflictid, merge.conflicts{grainid}(conflictid).merge);        
            phase.setAllEquals(grainid, conflictid, merge.conflicts{grainid}(conflictid).allequals);
        end
        
        phase.setHasConflicts(grainid, merge.hasConflicts(grainid));
        phase.setNofConflicts(grainid, merge.nofConflicts(grainid));
        
        fprintf('%04d/%04d',grainid,length(phase.grains))
    end
    sample.phases{phaseid} = phase;
end

if save_flag
    disp(' ')
    disp(['Updating file ' filename '...'])
    save(fullfile(filedir,'sample.mat'),'sample','-v7.3');
end


end % end of function
