function c_axismap = gtCaxisCmap(phaseid, bodge)
% GTCAXISCMAP  Make a colourmap according to c-axis orientation
%     c_axismap = gtCaxisCmap(phaseid, bodge)
%     ---------------------------------------
%     Loads parameters.mat and 4_grains/phase_##/r_vectors.mat
%     Saves c_axis.mat, map.mat and c_axismap.mat
%
%     INPUT:
%       phaseid   = phase number <int> {1}
%       bodge     = in degrees {0}
%
%     OUTPUT:
%       c_axismap = c_axis colourmap calculated from r_vectors list as produced by gtReadGrains
%
%     r_vectors -> c-axis -> phi/psi -> hsl -> rgb colormap
%     use psi to give brightness; phi to give colour
%
%     Version 002 28-06-2012 by LNervo
%       Update to version 2 of parameters; cleaning formatting

if ~exist('phaseid','var') || isempty(phaseid)
    phaseid = 1;
end
if ~exist('bodge','var') || isempty(bodge)
    bodge = 0;
end

parameters = [];
r_vectors  = [];
load('parameters.mat');
load(fullfile('4_grains',sprintf('phase_%02d',phaseid),'r_vectors.mat'));
 
all_hkils=[];
hkil = [...
    0 0 0 2; ...
    ];
for i = 1:size(hkil,1)
    all_hkils = [all_hkils ; gtGetReflections_sab(hkil(i,:))];
end
% normalise hkls vector
% going to cartesian reciprocal space + normalisation of the cartesian
% space
for i=1:size(all_hkils)
    all_hkls(i,1)= all_hkils(i,1) + 0.5 * all_hkils(i,2);
    all_hkls(i,2)= 3^0.5/2 *all_hkils(i,2);
    all_hkls(i,3)= all_hkils(i,4);

    all_hkls(i,1)=all_hkls(i,1)*2/(sqrt(3)*parameters.cryst(phaseid).latticepar(1));
    all_hkls(i,2)=all_hkls(i,2)*2/(sqrt(3)*parameters.cryst(phaseid).latticepar(1));
    all_hkls(i,3)=all_hkls(i,3)/parameters.cryst(phaseid).latticepar(3);
end
tmp = sqrt(sum((all_hkls.*all_hkls),2));
normalised_hkls = all_hkls./(repmat(tmp,1,3));
% unification des notations pour la suite
all_hkls = [];
all_hkls = all_hkils;


for i=1:size(r_vectors,1)
    g = Rod2g(r_vectors(i,2:4));
    
    disp([num2str(bodge) ' degrees bodge here!'])
    g=[cosd(bodge) sind(bodge) 0; -sind(bodge) cosd(bodge) 0; 0 0 1]*g;
    
    all_normals = (g * normalised_hkls')';
    c_axis(i,1)=r_vectors(i,1);
    if all_normals(2,3)>=0
        c_axis(i,2)=all_normals(2,1);
        c_axis(i,3)=all_normals(2,2);
        c_axis(i,4)=all_normals(2,3);
    else
        c_axis(i,2)=all_normals(1,1);
        c_axis(i,3)=all_normals(1,2);
        c_axis(i,4)=all_normals(1,3);
    end
end


save('c_axis.mat','c_axis'); % list of the c axis


psi=acosd(c_axis(:,4));
phi=atan2(c_axis(:,3), c_axis(:,2));
% phi=atan2(c_axis(:,2), c_axis(:,3));
%get everything in degrees, and on the right interval
phi=phi*180/pi;
% %want all psi between 0 and 90
% psi(find(psi>90))=180-psi(find(psi>90));
% %if we change psi, should also change phi
% phi(find(psi>90))=phi(find(psi>90))+180;

dummy=find(psi>90);
psi(dummy)=180-psi(dummy);
%if we change psi, should also change phi
phi(dummy)=phi(dummy)+180;

phi(find(phi<0))=phi(find(phi<0))+360;
phi(find(phi>360))=phi(find(phi>360))-360;

%use hsl2rgb.m
%hue
h=phi/360;
%saturation
s=ones(size(h));
%lightness (white //z, black in x-y plane)
l=0.9-(0.8*(psi/90));

rgb=hsl2rgb([h s l]);

%add black background and expand list length of max(grainid)+1
c_axismap=zeros(max(c_axis(:,1))+1, 3);
for i=1:length(c_axis)
  c_axismap(c_axis(i,1)+1, :)=rgb(i,:);
end

%save the caxis colourmap
save('c_axismap.mat','c_axismap');

map = gtIVPhexCmap(r_vectors,bodge);
save('map.mat','map');

end % end of function
