
%make a figure showing the CaxisCmap
%present in steorographic projection

%colours - whether from gtCaxisCmap or from gtAnalyseCrackPlane - are
%calculated from vectors in instrument coordinate system.  
%TOMO: x: left to right; y: top to bottom; z: positive is into page/screen
%INST: x: //y tomo; y: //x tomo; z: // negative z tomo

%colours: red-> green-> blue-> red as phi=0( // inst x
%axis)-> phi=120-> 240-> 360, anticlockwise.

%therefore red is at bottom of the screen, green is uppper right, blue is
%upper left.


function gtCaxisCmap_key

id=figure;

inc=pi/100;

for phi=-inc:inc:(2*pi)+inc; %around z-axis
    for psi=0:inc:pi/2; %away from z axis

        r1=tan(psi/2);
        r2=tan((psi+inc)/2);

        %offset phi by -(pi/2) to put phi=0 at bottom of the image
        x=[r1*cos(phi-(pi/2)) r1*cos(phi+inc-(pi/2)) r2*cos(phi+inc-(pi/2)) r2*cos(phi-(pi/2))];
        y=[r1*sin(phi-(pi/2)) r1*sin(phi+inc-(pi/2)) r2*sin(phi+inc-(pi/2)) r2*sin(phi-(pi/2))];

        %centre of patch to give mean colour
        mpsi=psi+inc/2;
        mphi=phi+inc/2;

        %keep edges within limits
        if mphi<0
            mphi=0;
        end
        if mphi>2*pi
            mphi=2*pi;
        end
        if mpsi>pi/2
            mpsi=pi/2;
        end

        %calculate colour
        h=mphi/(2*pi);
        %saturation
        s=ones(size(h));
        %lightness (white //z, black in x-y plane)
        l=0.9-(0.8*(mpsi/(pi/2)));

        rgb=hsl2rgb([h s l]);

        %draw patch
        p=patch(x,y,rgb);
        set(p, 'edgecolor', 'none');
    end
end

axis square
id=gca(id);
set(id, 'xticklabel', '');
set(id, 'yticklabel', '');
set(id, 'xcolor', 'w')
set(id, 'ycolor', 'w')

