
function gtPlotHexagon(grains, r_vectors, angle, cmap)

%make a figure containing subplots of the unit cells of the selected grains
%angle is the angle of the section plane, defined as in
%gtShowSampleSurface
%can pass in a colormap as well, so colours match the section

%as in gtShowSampleSurface
%Deal with coordinate systems.  R-vector orientation data in the instrument
%system: x//beam, z upwards, y towards door.
%In the reconstructed tomography/grain map data, z is downwards, y//x
%instruments, x//y instrument.
%Finally present all information in the frame of the tomo data.


if ~exist('cmap', 'var')
    %if no colourmap passed in, use red
    cmap=zeros(size(r_vectors, 1), 3);
    cmap(:,1)=1;
end


% patch object hexagonal prism
%12 corners
%[u v x w]
corners4=[2 -1 -1 3;...
    -1 2 -1 3;...
    -1 -1 2 3;...
    1 1 -2 3;...
    1 -2 1 3;...
    -2 1 1 3];
corners4=[corners4; corners4];
corners4(7:12, 4)=-3;%lower corners

%turn these into 3 index coords
corners3(:,3)=corners4(:,4);
corners3(:,1)=(corners4(:,1)-corners4(:,3))*cosd(30);
corners3(:,2)=corners4(:,2)-((corners4(:,1)+corners4(:,3))*sind(30));
corners3=corners3./repmat(sqrt(sum((corners3.*corners3),2)), 1,3);

id=figure;

%apply the R-vector
for i=1:length(grains)

    grain=grains(i);
    R=r_vectors(find(r_vectors(:,1)==grain),2:4);
    g=Rod2g(R);
    corners3a=(g*corners3')';

    %allow for the two coordinate systems.  Transform from instrument to
    %reconstructed tomo coordinates: x-->y y-->x z-->-z
    corners3a=[corners3a(:,2) corners3a(:,1) -corners3a(:,3)]; 
    
    %do the rotate to follow the the section plane
    corners3b = ([cosd(angle) sind(angle) 0; -sind(angle) cosd(angle) 0;0 0 1]*corners3a')';

    %write these corners into the correct format for patch

    %corners3a is "vertices"
    hex_faces=[1 4 2 6 3 5; 7 11 9 12 8 10];
    rec_faces=[1 7 10 4;...
        4 2 8 10;...
        2 6 12 8;...
        6 3 9 12;...
        3 5 11 9;...
        5 1 7 11];

    subplot(1, length(grains), i);
    %reference hex
    %patch('Vertices', corners3, 'Faces', hex_faces, 'FaceColor', 'b', 'FaceAlpha', 0.4)
    %patch('Vertices', corners3, 'Faces', rec_faces, 'FaceColor', 'b', 'FaceAlpha', 0.4)
    %reference background like the section plane
    xpos=min(mean(corners3b([1 4 2 6 3 5], 1)), mean(corners3b([7 11 9 12 8 10], 1)));
    section_plane_vertices=[xpos 1 1; xpos 1 -1; xpos -1 1; xpos -1 -1];
    section_plane_face=[1 2 4 3];
    patch('Vertices', section_plane_vertices, 'Faces', section_plane_face, 'FaceColor', 'k', 'FaceAlpha', 0.4)
    %including the rotation for sectioning
    patch('Vertices', corners3b, 'Faces', hex_faces, 'FaceColor', cmap(grain+1,:), 'FaceAlpha', 1)
    patch('Vertices', corners3b, 'Faces', rec_faces, 'FaceColor', cmap(grain+1,:), 'FaceAlpha', 1)

    set(get(get(id, 'CurrentAxes'), 'Title'), 'String', sprintf('grain %d unit cell', grain))
    set(get(get(id, 'CurrentAxes'), 'xLabel'),'String', 'x axis')
    set(get(get(id, 'CurrentAxes'), 'yLabel'),'String', 'y axis')
    set(get(get(id, 'CurrentAxes'), 'zLabel'),'String', 'z axis')
    set(get(id, 'CurrentAxes'), 'zdir','reverse')
    set(get(id, 'CurrentAxes'), 'xdir','reverse')
    %need to mirror twice to stay consistant with tomo
    set(get(id, 'CurrentAxes'), 'view', [90 0])

    axis tight
    axis vis3d
end







