function [fedpars, gv] = gtFedSetupT0(gv, varargin)

% setup the equations for solving the thingy
% choose which components are active, and how to calculate T0
%
% select which blobs to use - this means selecting the relevant data from
% gv(i).uc0bl_All -->  gv(i).uc0bl
%
% if a second arguement is supplied, try to do everything automatically
% based on fedpars.strategy


if length(varargin) == 1
    phase = varargin{1};
else
    phase = 0;
end

load fedpars


if phase == 0 || phase == ~isfield(fedpars, 'strategy')
    % get the relevent fedpars parameters from user
    fedpars.dindex     = inputwdefaultnumeric('enter the desired dindex vector [Rx Ry Rz e11 e22 e33 e23 e13 e12]:', '[1 1 1 0 0 0 0 0 0]');
    fedpars.T0strategy = inputwdefault('enter the desired T0 strategy A/B :', 'B');
    fedpars.niter      = inputwdefaultnumeric('enter the number of iterations', '100');
    fedpars.usebl      = inputwdefaultnumeric('enter which blobs should be used :', ['[' num2str(fedpars.loadbl) ']']);
    % may need something nicer here

elseif phase == 1
    % read these options from fedpars
    fedpars.dindex     = fedpars.strategy.a.dindex;
    fedpars.T0strategy = fedpars.strategy.a.T0strategy;
    fedpars.niter      = fedpars.strategy.a.niter;
    fedpars.usebl      = fedpars.strategy.a.usebl;
    fedpars.dsteplim   = fedpars.strategy.a.dsteplim;
    
elseif phase == 2
    % read these options from fedpars
    fedpars.dindex     = fedpars.strategy.b.dindex;
    fedpars.T0strategy = fedpars.strategy.b.T0strategy;
    fedpars.niter      = fedpars.strategy.b.niter;
    fedpars.usebl      = fedpars.strategy.b.usebl;
    fedpars.dsteplim   = fedpars.strategy.b.dsteplim;
    
    
end

% Now deal with the data input

% blobs should be paired - make sure that if one blob is removed, so is the
% other
%%% PR - I'm not sure this is always necessary, could just have a warning instead
r = setdiff(fedpars.loadbl, fedpars.usebl);
for i = 1:length(r)
    pair  = floor((r(i)+1)/2);
    pairA = 2*(pair-1)+1;
    pairB = 2*(pair-1)+2;
    fedpars.usebl(fedpars.usebl==pairA) = [];
    fedpars.usebl(fedpars.usebl==pairB) = [];
end
nbl = length(fedpars.usebl);

% other fedpars fields that depend on the number of blobs used
fedpars.sufac = 10*ones(3, nbl/2);
fedpars.sumax = inf(3, nbl/2);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% calculate the T matrices
for i=1:length(gv)
    
    % some fields of gv need to be pre-allocated to the correct size
    gv(i).T02   = NaN(9,3*nbl/2);
    gv(i).uc0im = NaN(3,nbl);  % initial (reference state) absolut [u,v,w] vector in image
    gv(i).uc0bl = NaN(3,nbl);  % initial (reference state) [u,v,w] vector in blob (relative to blob origin, i.e. not the blob center)
    gv(i).uc    = NaN(3,nbl); 

    gv(i).fu  = NaN(3,nbl);    % actual force
    gv(i).fu2 = NaN(3,nbl/2);  % actual force, paired
    gv(i).su  = NaN(3,nbl);    % actual speed
    gv(i).su2 = NaN(3,nbl/2);  % actual speed, paired
    
	  U0_allbl = zeros(3*nbl,9);
		
		% collect all gv blob information
		for j = 1:nbl
			% which blob are we interested in?
			b = fedpars.usebl(j);
			
			% collect the U0 terms
			U0_allbl((j-1)*3+1:j*3,:) = gv(i).U0(:,:,b);
			
			% collect the uc0 terms
			gv(i).uc0im(:,j) = gv(i).uc0im_All(:,b);
			gv(i).uc0bl(:,j) = gv(i).uc0bl_All(:,b);
			gv(i).uc(:,j) = gv(i).uc_All(:,b);
		end
		
		% Calculate the T0 matrices
		if strcmpi(fedpars.T0strategy, 'A')
			% solve for T0 as normal
			[Usvd,Ssvd,Vsvd] = svd(U0_allbl,0);
			gv(i).T0 = Vsvd*diag(1./diag(Ssvd))*Usvd';
			% force lines of T0 to zeros
			gv(i).T0(~fedpars.dindex, :) = 0;
			
		elseif strcmpi(fedpars.T0strategy, 'B')
			% remove terms from U0_allbl
			U0_allbl(:, ~fedpars.dindex) = [];
			[Usvd,Ssvd,Vsvd] = svd(U0_allbl,0);
			tmpT0 = Vsvd*diag(1./diag(Ssvd))*Usvd';
			% restore to standard dimensions
			gv(i).T0 = zeros(9, 3*nbl);
			gv(i).T0(fedpars.dindex, :) = tmpT0;
			
		else
			error('fedpars.T0strategy not recognised! problem...')
		end
		
		% Calculate the T02 matrices
		Tau = gv(i).T0(:,1:6:end);
		Tav = gv(i).T0(:,2:6:end);
		Taw = gv(i).T0(:,3:6:end);
		
		Tbu = gv(i).T0(:,4:6:end);
		Tbv = gv(i).T0(:,5:6:end);
		Tbw = gv(i).T0(:,6:6:end);
		
		gv(i).T02(:,1:3:end) = (Tau+Tbu)/2;
		gv(i).T02(:,2:3:end) = (Tav-Tbv)/2;
		gv(i).T02(:,3:3:end) = (Taw+Tbw)/2;

end

% save updated structures
disp(['saving updated fedpars and gv in ' fedpars.filename])
save(fedpars.filename, 'fedpars', 'gv', '-append')


