function gh = gtCrystSymOpHexagonal(spacegroup)
% GTCRYSTSYMOPHEXAGONAL  Gives crystal symmetry operators for hexagonal lattices
%     gh = gtCrystSymOpHexagonal(spacegroup)
%     --------------------------------------
%
%     Only implemented for spacegroup 663, 194, 152, 167
%
%     INPUT:
%       spacegroup
%
%     OUTPUT:
%       gh(i).g - structure array of the operator matrices
%

if ~exist('spacegroup','var') || isempty(spacegroup)
    parameters = [];
	load('parameters.mat');
	spacegroup = parameters.cryst.spacegroup;
end

switch spacegroup
    
case {663, 194}

% For spacegroup 663 and 194, they can be used with row or column vectors
% (perhaps for other spacegroups as well).

%This function returns the  12 symmetry operators for the hexagonal crystal
gh(1).g=[...
  1 0 0 0;...
  0 1 0 0;...
  0 0 1 0;...
  0 0 0 1];

gh(2).g=[...
  0 0 1 0;...
  1 0 0 0;...
  0 1 0 0;...
  0 0 0 1];

gh(3).g = [...
  0 1 0 0;...
  0 0 1 0;...
  1 0 0 0;...
  0 0 0 1];

gh(4).g=[...
  1 0 0 0;...
  0 1 0 0;...
  0 0 1 0;...
  0 0 0 -1] ;

gh(5).g=[...
  0 0 1 0;...
  1 0 0 0;...
  0 1 0 0;...
  0 0 0 -1];

gh(6).g = [...
   0 1 0 0;...
   0 0 1 0;...
   1 0 0 0;...
  0 0 0 -1];

gh(7).g=[...
  -1 0 0 0;...
  0 -1 0 0;...
  0 0 -1 0;...
  0 0 0 1] ;

gh(8).g=[...
  0 0 -1 0;...
  -1 0 0 0;...
  0 -1 0 0;...
  0 0 0 1];

gh(9).g = [...
  0 -1 0 0;...
  0 0 -1 0;...
  -1 0 0 0;...
  0 0 0 1];

gh(10).g=[...
  -1 0 0 0;...
  0 -1 0 0;...
  0 0 -1 0;...
  0 0 0 -1] ;

gh(11).g=[...
  0 0 -1 0;...
  -1 0 0 0;...
  0 -1 0 0;...
  0 0 0 -1];

gh(12).g = [...
  0 -1 0 0;...
  0 0 -1 0;...
  -1 0 0 0;...
  0 0 0 -1];
	
case {152, 167}  % trigonal symmetry
	% 6 operators, also return in 3 index format
	
	% however, this doesn't seem right when looking at the alumina
	% datasets... more work to do.
        
   %reference
gh(1).g=[...
  1 0 0 0;...
  0 1 0 0;...
  0 0 1 0;...
  0 0 0 1] ;

% rotate 120 around z
gh(2).g=[...
  0 1 0 0;...
  0 0 1 0;...
  1 0 0 0;...
  0 0 0 1] ;

% rotate 240 around z
gh(3).g=[...
  0 0 1 0;...
  1 0 0 0;...
  0 1 0 0;...
  0 0 0 1] ;

% rotate 180 around x
gh(4).g=[...
  1 0 0 0;...
  0 0 1 0;...
  0 1 0 0;...
  0 0 0 -1] ;

% rotate 180 around y
gh(5).g=[...
  0 0 1 0;...
  0 1 0 0;...
  1 0 0 0;...
  0 0 0 -1] ;

% rotate 180 around dummy
gh(6).g=[...
  0 1 0 0;...
  1 0 0 0;...
  0 0 1 0;...
  0 0 0 -1] ;

% 3 axis 

%reference
gh(1).g3=[...
  1 0 0;...
  0 1 0;...
  0 0 1] ;

% hkil -> ihkl
gh(2).g3 = [...
    cosd(120) sind(120) 0;...
    -sind(120) cosd(120) 0;...
    0 0 1];

% rotate -120 around z
% hkil -> kihl
gh(3).g3 = [...
    cosd(-120) sind(-120) 0;...
    -sind(-120) cosd(-120) 0;...
    0 0 1];

% rotate 180 around hex axis 1 (// y in cart)
gh(4).g3=[...
  -1 0 0;...
  0 1 0;...
  0 0 -1] ;
% rotate 180 around hex axis 2
gh(5).g3= gh(2).g3*gh(4).g3*gh(3).g3;
% rotate 180 around hex axis 3
gh(6).g3= gh(3).g3*gh(4).g3*gh(2).g3;
 

otherwise
error('Spacegroup is not supported.')
     

end % end switch spacegroup

end % end of function

