/*
 * internal_cell_sum.cpp
 *
 *  Created on: Jul 11, 2012
 *
 * Nicola Vigano', 2012, ID11 @ ESRF vigano@esrf.eu
 */

#include "internal_cell_defs.h"

void mexFunction( int nlhs, mxArray * plhs[], int nrhs, const mxArray * prhs[] )
{
  if (nrhs != 2) {
    mexErrMsgIdAndTxt("C_FUN:cell_sum:wrong_argument",
        "Not enough arguments! you need to provide two cell arrays");
  }
  if (!mxIsCell(prhs[0])) {
    mexErrMsgIdAndTxt("C_FUN:cell_sum:wrong_argument",
        "The first argument should be a Cell array");
  }
  if (!mxIsCell(prhs[1])) {
    mexErrMsgIdAndTxt("C_FUN:cell_sum:wrong_argument",
        "The second argument should be a Cell array");
  }
  const mwSize numElems1 = mxGetNumberOfElements(prhs[0]);
  const mwSize numElems2 = mxGetNumberOfElements(prhs[1]);

  if (numElems1 != numElems2) {
    mexErrMsgIdAndTxt("C_FUN:cell_sum:wrong_argument",
        "The Cell arrays should have the same size");
  }

  plhs[0] = (mxArray *) prhs[0];

  const inner_sum<const double, const double> funcNonVect = inner_sum<const double, const double>();
#if defined(__SSE2__) || defined(__SSE2_MATH__)
  inner_sum<const v2df, const v2df> func;
  cell_iteration_sse<false>(plhs[0], prhs[1], func, funcNonVect);
#else
  cell_iteration<false>(plhs[0], prhs[1], funcNonVect);
#endif
}

