/*
 * internal_cell_prod_scalar_assign.cpp
 *
 *  Created on: Jul 12, 2012
 *
 * Nicola Vigano', 2012, ID11 @ ESRF vigano@esrf.eu
 */

#include "internal_cell_defs.h"

void mexFunction( int nlhs, mxArray * plhs[], int nrhs, const mxArray * prhs[] )
{
  if (nrhs != 2) {
    mexErrMsgIdAndTxt("C_FUN:cell_exponent_wrong_argument",
        "Not enough arguments! you need to provide a cell array and a double");
  }
  if (!mxIsCell(prhs[0])) {
    mexErrMsgIdAndTxt("C_FUN:cell_exponent_wrong_argument",
        "The first argument should be a Cell array");
  }
  if (!mxIsDouble(prhs[1])) {
    mexErrMsgIdAndTxt("C_FUN:cell_exponent_wrong_argument",
        "The second argument should be a double containing the scalar");
  }
  const double scalar = *mxGetPr(prhs[1]);

  plhs[0] = (mxArray *) prhs[0];

  inner_sum_scalar<const double, const double> funcNonVect(scalar);
#if defined(__SSE2__) || defined(__SSE2_MATH__)
  inner_sum_scalar<const v2df, const v2df> func((v2df) {scalar, scalar});
  cell_iteration_sse<false>(plhs[0], prhs[0], func, funcNonVect);
#else
  cell_iteration<false>(plhs[0], prhs[0], funcNonVect);
#endif
}


