/**
 * Does exactly the same as 'mean2' function from Imaging toolbox.
 *
 * The aim was to get rid of license requirements, and test possible
 * optimization techniques.
 *
 * Nicola Vigano', 2012, ID11 @ ESRF vigano@esrf.eu
 */

#include "mex.h"

#define ROUND_DOWN(x, s)  ((x) & ~((s)-1))
#define ROUND_DOWN_2(x)   ((x) & ~1)
#define ROUND_DOWN_4(x)   ((x) & ~3)
#define ROUND_DOWN_8(x)   ((x) & ~7)
#define ROUND_DOWN_16(x)  ((x) & ~15)
#define ROUND_DOWN_32(x)  ((x) & ~31)

#ifdef HAVE_OMP
# include <omp.h>
#endif
typedef double v2df __attribute__ ((vector_size (16)));

void mexFunction( int nlhs, mxArray * plhs[], int nrhs, const mxArray * prhs[] )
{
  /* Incoming image dimensions */
  const mwSize tot_pixels = mxGetNumberOfElements(prhs[0]);
  const mwSize totUnroll32Pixels = ROUND_DOWN_32(tot_pixels);

  /* Pointers to incoming matrices: */
  const double * const __restrict image_in = mxGetPr(prhs[0]);

  double temp_av = 0;
  v2df accumul = {0, 0};

#pragma omp parallel for reduction(+:accumul)
  for(mwIndex count = 0; count < totUnroll32Pixels; count += 32) {
    accumul += ( *((v2df *)&image_in[count+0]) + *((v2df *)&image_in[count+2])
               + *((v2df *)&image_in[count+4]) + *((v2df *)&image_in[count+6])
               + *((v2df *)&image_in[count+8]) + *((v2df *)&image_in[count+10])
               + *((v2df *)&image_in[count+12]) + *((v2df *)&image_in[count+14])
               + *((v2df *)&image_in[count+16]) + *((v2df *)&image_in[count+18])
               + *((v2df *)&image_in[count+20]) + *((v2df *)&image_in[count+22])
               + *((v2df *)&image_in[count+24]) + *((v2df *)&image_in[count+26])
               + *((v2df *)&image_in[count+28]) + *((v2df *)&image_in[count+30]) );
  }
  for(mwIndex count = totUnroll32Pixels; count < tot_pixels; count++) {
    temp_av += image_in[count];
  }
  const double * const __restrict accumuld = (double *)&accumul;

  /* Create a matrix for the return argument */
  plhs[0] = mxCreateDoubleScalar((temp_av + accumuld[0] + accumuld[1]) / tot_pixels);

//  double temp_av = 0;
//# ifdef __SSE2__
//  v2df accumul = {0, 0};
//# endif
//
//#ifdef HAVE_OMP
//# ifdef __SSE2__
//#   pragma omp parallel private(accumul)
//# else
//#   pragma omp parallel
//# endif
//#endif
//  {
//#ifdef __SSE2__
//# pragma omp for
//#else
//# pragma omp for reduction(+:temp_av)
//#endif
//    for(mwIndex count = 0; count < totUnroll4Pixels; count += 4) {
//#ifdef __SSE2__
//      accumul += ( *((v2df *)&image_in[count]) + *((v2df *)&image_in[count+2]) );
//#else
//      temp_av += ( image_in[count+0] + image_in[count+1]
//                 + image_in[count+2] + image_in[count+3]);
//#endif
//    }
//    for(mwIndex count = totUnroll4Pixels; count < tot_pixels; count++) {
//      temp_av += image_in[count];
//    }
//#ifdef __SSE2__
//  const double * const accumuld = (double *)&accumul;
//# pragma omp atomic
//  temp_av += accumuld[0] + accumuld[1];
//#endif
//  }
//  temp_av /= tot_pixels;
//
//  /* Create a matrix for the return argument */
//  plhs[0] = mxCreateDoubleScalar(temp_av);
}
