/*
 * internal_array_defs.h
 *
 *  Created on: Jul 17, 2012
 *
 * Nicola Vigano', 2012, ID11 @ ESRF vigano@esrf.eu
 */

#ifndef INTERNAL_ARRAY_DEFS_H_
#define INTERNAL_ARRAY_DEFS_H_

#include <cmath>
#include <omp.h>

using namespace std;

template<typename SizeType, typename Type>
class soft_threshold {
  const Type thr;
public:
  soft_threshold(const Type & _thr) : thr(_thr) { }

  void operator()(Type * const __restrict array, const SizeType & numElems);
  void operator()(Type * const __restrict outArray,
      const Type * const __restrict inArray, const SizeType & numElems);
};

template<typename SizeType, typename Type>
inline void
soft_threshold<SizeType, Type>::operator()(Type * const __restrict array,
    const SizeType & numElems)
{
#pragma omp prallel for
  for(SizeType count = 0; count < numElems; count++)
  {
    const Type & oldVal = array[count];
    const Type temp = oldVal - thr;
    array[count] = copysign((temp + fabs(temp)) / 2, oldVal);
  }
}

template<typename SizeType, typename Type>
inline void
soft_threshold<SizeType, Type>::operator()(Type * const __restrict outArray,
    const Type * const __restrict inArray, const SizeType & numElems)
{
#pragma omp prallel for
  for(SizeType count = 0; count < numElems; count++)
  {
    const Type & oldVal = inArray[count];
    const Type temp = oldVal - thr;
    outArray[count] = copysign((temp + fabs(temp)) / 2, oldVal);
  }
}


#endif /* INTERNAL_ARRAY_DEFS_H_ */
