function gtDBUpdateColumn(table_name,pattern,expression)
% GTDBUPDATECOLUMN  Access a column in a table to be updated in an
%                   expression
%
%     gtDBUpdateColumn(table_name,field_name,expression)
%     --------------------------------------------------
%     INPUT:
%       table_name = name of the table in the database <string>
%       pattern    = variable or pattern name; can be part of the varialbe
%                    name; i.e. 'CentroidY' or 'Y' <string>
%       expression = Expression to be applied to all the values in the
%                    column(s) given by pattern. Use '_var_' as the variable name 
%                    i.e. expression = '_var_ = _var_ + 1' <string>

% show columns for the table
[fields_list,~,~,~,~,~]=mym(['SHOW COLUMNS FROM ' table_name])

% get fields corresponding to pattern
[mod_fields,~,~,~,~,~]=mym(['SHOW COLUMNS FROM ' table_name ' WHERE Field LIKE "%' pattern '%"'])



% prepare expression to be applied to each column
mym_expr=cell(size(mod_fields));
if ~isempty(mod_fields)
    for i=1:length(mod_fields)
        mym_expr{i}=strrep(expression,'_var_',mod_fields{i});
        check=inputwdefault(['Is the expression correct: ' mym_expr{i} ' ? '],'y');
        if strcmpi(check,'n')
            mym_expr{i}=input('Insert the right expression (between single quotes) [''_var_'' can be used]: ');
            mym_expr{i}=strrep(mym_expr{i},'_var_',mod_fields{i});
        end
    end
    
    
    disp(['Expressions to be applied for the table ' table_name])
    disp(mym_expr)
    
    for i=1:length(mod_fields)
        check=inputwdefault(['Do you want to apply this expression: ' mym_expr{i} ' ? '],'y');
        if strcmpi(check,'y')
            mym(['UPDATE ' table_name ' SET ' mym_expr{i}])
            disp(['Updated ' table_name ' : ' mym_expr{i}])
        end 
    end

end


end % end of function