function [r,c,sx,sy]=distortion_createnodes(varargin)
%
% FUNCTION distortion_createnodes(im,crop,fname_mat)
%
% Finds a regular pattern in image 'im' and writes the node coordinates in
% the given 'fname_mat' matlab data file. That can be used in 
% distortion_createmap.m for the creation of distortion maps.
%

crop=false;

switch nargin
  case 0
    disp('Specify the source image, please!')
    return
  case 1
    im=varargin{1};
    savefile=false;
  case 2
    im=varargin{1};
    if varargin{2}==1 | strcmpi(varargin{2},'crop')
      crop=true;
    end
    savefile=false;
  case 3
    im=varargin{1};
    if varargin{2}==1 | strcmpi(varargin{2},'crop')
      crop=true;
    end
    fname_mat=varargin{3};
    savefile=true;
  otherwise
    disp('Too many input arguments!')
    help mfilename
    return
end

doscale = false

% scale im (.. %) between 0 and 1
lim=gtSetColourLimits(im,0);
im=1-(im-lim(1))./(lim(2)-lim(1));



if crop==1
  disp(' ')
  disp('Choose a region completely filled with regular features')
  disp(' ')
  figure
  [im,rect]=imcrop(im,[0 1]); % display between 0 and 1
  sx=rect(4);
  sy=rect(3);
  imc=imcrop(im,[sy*0.375 sx*0.375 sy*0.25 sx*0.25]);
  imshow(imc,[0 1])
else
  sx=size(im,1);
  sy=size(im,2);
  imshow(im,[])
  pause(1)
  imc=imcrop(im,[sy*0.375 sx*0.375 sy*0.375 sx*0.375]);
  imshow(imc,[0 1])
end

%%% Comment:
%%% Rect gives the crop boundaries according to:
%%% orim= original full image, then cut
%%% orim(1:round(rect(2))-1,:)=[];
%%% orim(size(im,1)+1:end,:)=[];
%%% orim(:,1:round(rect(1))-1)=[];
%%% orim(:,size(im,2)+1:end)=[];

disp(' ')
disp('Select a repeated feature...')
disp(' ')
feature=imcrop(imc);
title('Calculating...')
xlabel('y')
ylabel('x')
set(gca,'XAxisLocation','top')
drawnow

%  Since we are using convolution, prepare the footprint
%  accordingly
feature = fliplr(flipud(feature));

if doscale
  % oversample the image to give better resolution
  scale=1;
  im=imresize(im,scale);
  feature=imresize(feature,scale);
end
%%

tic

%  Convolve
C = conv2(im, feature, 'same');

D=C;
D(find(D<max(D(:)*0.5)))=0;  % get rid of weak peaks

%a=round(length(feature)*0.4);  % make a guess 20% of the feature size ***0.4
a=round(length(feature)*1);

% do a neighbourhood sort
highest=ordfilt2(D,a*a,ones(a));

mask=(C==highest);  % only nearest pixel :(

[r,c,v]=find(mask);

for i=1:length(r)
  ce=[r(i),c(i)]+min2par(C([r(i)-1 r(i) r(i)+1],[c(i)-1 c(i) c(i)+1]));
  r(i)=ce(1);
  c(i)=ce(2);
end

% now revert to the original scale
if doscale
  r=r./scale;
  c=c./scale;
end
toc

if savefile==true  %%% added by Peter
  save(fname_mat,'r','c','im','feature','sx','sy'); 
  disp(sprintf('Nodes and image are saved in: %s',fname_mat))
end

imshow(im,[])
title('Nodes found:')
xlabel('y')
ylabel('x')
set(gca,'XAxisLocation','top')
hold on
plot(c,r,'r+')
drawnow

%% Subfunctions (taken from correlate.m)

function mi=min2par(arg)

[X,Y]=meshgrid(-1:1,-1:1);
r=Y(:);
c=X(:);
xt=quad2func(r,c);
a=xt\arg(:);
mi=[-a(2) -a(3)]/[2*a(5) a(4);a(4) 2*a(6)];

%-------------------------
% function xt=quad2func(x,y)
% quadratic function of 2 parameters x and y
% size(xt)=[n 6] with n the number of observations
% for functions linear in the parameters:
% z = xt*a with size(a)=[6 1]
% i.e. z=a(1)+a(2)*x+a(3)*y+a(4)*x.*y+a(5)*x.^2+a(6)*y.^2
% if one has n observations given by z (size(z)=[n 1])
% the least squares estimation of a is
% a=xt\z;

function xt=quad2func(x,y)

xt=[ones(size(x)) x y x.*y x.^2 y.^2];
