function [proj,difspot,bb]=gtForwardProject(gv,grain,parameters,index)
% INPUTS:  
% gv         binary 3D grain volume of dimensions acq.bb(3) acq.bb(3)
% acq.bb(4)
% grain      grain{i} entry of the grain
% parameters parameters structure
% index      projection indices to be calculated
% OUTPUTS:  
% proj       2D projection on the detector...

proj=zeros(parameters.acq.ydet,parameters.acq.xdet,max(index));

dist=parameters.acq.dist/parameters.acq.pixelsize;   %rotation axis to detector distance

bb=parameters.acq.bb;

[i,j,k]=ind2sub(size(gv),find(gv));   % voxel coordinates in Matlab array
[x,y,z]=gtTrIndToSam(i,j,k,parameters);

for nr=index   %

  o=grain.omega(nr);
  t=grain.theta(nr);
  e=grain.eta(nr);   % sign depends if we look into teh beam or not 
  
  % calculate voxel coordinates in Lab system
  
  [xl,yl,zl]=gtTrSamToLab(x,y,z,o);
  
  n=[cosd(2*t);sind(2*t)*sind(e);sind(2*t)*cosd(e)];  % direction of the diffracted beam in Lab coordinates
  
  
  for nv=1:length(x)
	
	xi=xl(nv);
	yi=yl(nv);
	zi=zl(nv);
	
	% direct beam image
	if 1
	  Imx=parameters.acq.rotx-yi;
	  Imy=parameters.acq.ydet/2+0.5-zi;

	  fracx=Imx-floor(Imx);
	  fracy=Imy-floor(Imy);

	  Ix=floor(Imx);
	  Iy=floor(Imy);

	  
	  proj(Iy,Ix,nr)=proj(Iy,Ix,nr)-(1-fracx)*(1-fracy);
	  proj(Iy,Ix+1,nr)=proj(Iy,Ix+1,nr)-fracx*(1-fracy);
	  proj(Iy+1,Ix,nr)=proj(Iy+1,Ix,nr)-(1-fracx)*fracy;
	  proj(Iy+1,Ix+1,nr)=proj(Iy+1,Ix+1,nr)-fracx*fracy;
	end % if
	%now solve  xi+ f*n(1)  = dist and calculate intersection point on the detector

	f=(dist-xi)/n(1);
	Pd=-(yi+f*n(2));
	Qd=zi+f*n(3);

	Imx=Pd+parameters.acq.rotx;
	Imy=parameters.acq.ydet/2+0.5-Qd;

	fracx=Imx-floor(Imx);
	fracy=Imy-floor(Imy);

	Ix=floor(Imx);
	Iy=floor(Imy);
	
	if Ix<0 || Iy<0 || Ix+1>size(proj,2) || Iy+1>size(proj,1)
	  %disp('projection out of detector');
	else
	  proj(Iy,Ix,nr)=proj(Iy,Ix,nr)+(1-fracx)*(1-fracy);
	  proj(Iy,Ix+1,nr)=proj(Iy,Ix+1,nr)+fracx*(1-fracy);
	  proj(Iy+1,Ix,nr)=proj(Iy+1,Ix,nr)+(1-fracx)*fracy;
	  proj(Iy+1,Ix+1,nr)=proj(Iy+1,Ix+1,nr)+fracx*fracy;
	end % if
  end  % for nv
  

  %proj(:,:,nr)=fliplr(proj(:,:,nr));  % because we look into the beam....
  
  extspot=gtCrop(proj(:,:,nr),parameters.acq.bb);
  name=sprintf('test3/extspot%d',nr);
  sdt_write(name,-extspot,'float32');
  
  
  %remove direct beam spot
  tmp=zeros(parameters.acq.bb(4),parameters.acq.bb(3));
  difspot=gtPlaceSubImage(tmp,proj(:,:,nr),parameters.acq.bb(1), parameters.acq.bb(2));
  
  a=regionprops(bwlabel(difspot)); 
 
  bb(nr,1)=ceil(a.BoundingBox(1));
  bb(nr,2)=ceil(a.BoundingBox(2));
  bb(nr,3)=a.BoundingBox(3);
  bb(nr,4)=a.BoundingBox(4);

  bb(nr,5)=round(a.Centroid(1));
  bb(nr,6)=round(a.Centroid(2));

  difspot=gtCrop(proj(:,:,nr),bb(nr,1:4));
  name=sprintf('test3/difspot%d.edf',nr);
  edf_write(difspot,name,'float32');
  name=sprintf('test3/difspot%d',nr);
  tmp=zeros(size(difspot)+200);
  difspot=gtPlaceSubImage(difspot,tmp,101,101);
  sdt_write(name,difspot,'float32');
  
end % for nr

save test3/lastrun proj bb
