function [proj,difspot,bb]=gtForwardProject2(gv,grain,parameters,index)
% INPUTS:  
% gv         binary 3D grain volume
% grain      grain structure of the grain
% parameters parameters structure
% index      projection indices to be calculated
% OUTPUTS:  
% proj       2D projection on the detector...

proj=zeros(parameters.acq.ydet,parameters.acq.xdet,max(index));

dist=parameters.acq.dist/parameters.acq.pixelsize;   %rotation axis to detector distance

for nr=index   %
  

  o=grain.omega(nr);  % changed to -
  t=grain.theta(nr);
  e=grain.eta(nr);   % changed to -

  % step 1: rotate the grain volume
  gvr=zeros(size(gv));
  for nz=1:size(gv,3)
    if gtImgMeanValue(gv(:,:,nz))>0
      gvr(:,:,nz)=imrotate(gv(:,:,nz),-o,'crop');
    end
  end

  s=regionprops(bwlabeln(gvr));
  cen=s.Centroid;
  % step 2: forward project each pixel onto the detector
  voxind=find(gvr>0);
  n=[sind(2*t)*sind(-e);sind(2*t)*cosd(e); -cosd(2*t)];  % direction of the diffracted beam in AREMIS coordinates (u,v,w)

  for nv=1:length(voxind)
    % transform voxel coordinates into the detector system - assuming the center of
    % rotation in the center of the sample volume

    %[y,x,z]=ind2sub(size(gvr),voxind(nv));   % sample system x and y axis are perpendicular to the z-rotation axis
    % u=  x-size(gvr,2)/2-0.5;
    % v=  size(gvr,3)/2-z+0.5;
    % w=  dist+y-size(gvr,1)/2-0.5;

%     [x,y,z]=ind2sub(size(gvr),voxind(nv));   % sample BB system x and y axis are perpendicular to the z-rotation axis
% 
%     u=  y-size(gvr,2)/2-0.5;
%     v=  size(gvr,3)/2-z+0.5;
%     w=  dist+x-size(gvr,1)/2-0.5;

    [y,x,z]=ind2sub(size(gvr),voxind(nv));   % sample system x and y axis are perpendicular to the z-rotation axis
      u=  -(x-size(gvr,2)/2-0.5);
      v=  -(z-size(gvr,3)/2-0.5);
      w=  -(y-size(gvr,1)/2-0.5)+dist;


    % direct beam image
    if 1
      Imx= u+parameters.acq.xdet/2+0.5;
      Imy=-v+parameters.acq.ydet/2+0.5;

      fracx=Imx-floor(Imx);
      fracy=Imy-floor(Imy);

      Ix=floor(Imx);
      Iy=floor(Imy);

      proj(Iy,Ix,nr)=proj(Iy,Ix,nr)-(1-fracx)*(1-fracy);
      proj(Iy,Ix+1,nr)=proj(Iy,Ix+1,nr)-fracx*(1-fracy);
      proj(Iy+1,Ix,nr)=proj(Iy+1,Ix,nr)-(1-fracx)*fracy;
      proj(Iy+1,Ix+1,nr)=proj(Iy+1,Ix+1,nr)-fracx*fracy;
    end % if
    %now solve  w+ f*n(3)  = 0 and calculate intersection point on the detector

    f=-w/n(3); %Dw=0=w+f*n(3)
    Du=u+f*n(1);
    Dv=v+f*n(2);

    Imx= Du+parameters.acq.xdet/2+0.5;
    Imy=-Dv+parameters.acq.ydet/2+0.5;

    fracx=Imx-floor(Imx);
    fracy=Imy-floor(Imy);

    Ix=floor(Imx);
    Iy=floor(Imy);

    if Ix<0 || Iy<0 || Ix>size(proj,2) || Iy>size(proj,1)
      disp('projection out of detector');
    else
      proj(Iy,Ix,nr)=proj(Iy,Ix,nr)+(1-fracx)*(1-fracy);
      proj(Iy,Ix+1,nr)=proj(Iy,Ix+1,nr)+fracx*(1-fracy);
      proj(Iy+1,Ix,nr)=proj(Iy+1,Ix,nr)+(1-fracx)*fracy;
      proj(Iy+1,Ix+1,nr)=proj(Iy+1,Ix+1,nr)+fracx*fracy;
    end % if
  end  % for nv

  %proj(:,:,nr)=fliplr(proj(:,:,nr));  %  in order to compare to experimental images...
  
  % locate direct beam spot
  %   u=  cen(1)-size(gvr,2)/2-0.5;
  %   v=  size(gvr,3)/2-cen(3)+0.5;
  %   Imx=u+parameters.acq.xdet/2+0.5;
  %   Imy=parameters.acq.ydet/2+0.5-v;
  %
  %   marker=zeros(parameters.acq.ydet,parameters.acq.xdet);
  %   marker(round(Imy),round(Imx))=1;
  %   dir=imreconstruct(marker,proj(:,:,nr));
  %
  %  a=regionprops(bwlabel(dir));

  extspot=gtCrop(proj(:,:,nr),parameters.acq.bb);
  name=sprintf('extspot%d',nr);
  sdt_write(name,extspot,'float32');


  %remove direct beam spot
  tmp=zeros(parameters.acq.bb(4),parameters.acq.bb(3));
  difspot=gtPlaceSubImage(tmp,proj(:,:,nr),parameters.acq.bb(1), parameters.acq.bb(2));
  % remove flip - just a test:
  % difspot=fliplr(difspot);
  a=regionprops(bwlabel(difspot));

  bb(nr,1)=ceil(a.BoundingBox(1));
  bb(nr,2)=ceil(a.BoundingBox(2));
  bb(nr,3)=a.BoundingBox(3);
  bb(nr,4)=a.BoundingBox(4);

  bb(nr,5)=round(a.Centroid(1));
  bb(nr,6)=round(a.Centroid(2));

  difspot=gtCrop(proj(:,:,nr),bb(nr,1:4));

  name=sprintf('test2/difspot%d',nr);
  tmp=zeros(size(difspot)+200);
  difspot=gtPlaceSubImage(difspot,tmp,101,101);
  sdt_write(name,difspot,'float32');

end % for nr

save test2/lastrun gv proj bb grain parameters
