function [proj,stack,bb,fulls]=gtForwardProjectASTRA(gv,grain,parameters,index)
% INPUTS:  
% gv         binary 3D grain volume of dimensions acq.bb(3) acq.bb(3)
% acq.bb(4)
% grain      grain{i} entry of the grain
% parameters parameters structure
% index      projection indices to be calculated
% OUTPUTS:  
% proj       full 2D image with direcgt and difracted beam projection on the detector...
% difspot    simulated difspot only
% bb         BB of simulateed spot
% reals   real diffraction spot
% realbb     real BoundingBox


proj=zeros(parameters.acq.ydet,parameters.acq.xdet,max(index));
fulls=zeros(parameters.acq.ydet,parameters.acq.xdet,max(index));
dist=parameters.acq.dist/parameters.acq.pixelsize;   %rotation axis to detector distance

direct_beam=1


[i,j,k]=ind2sub(size(gv),find(gv));   % voxel coordinates in Matlab array
[x,y,z]=gtTrIndToSam3D(i,j,k,parameters);

for nr=index   %

  o=grain.omega(nr);
  t=grain.theta(nr);
  e=grain.eta(nr);   % sign depends if we look into the beam or not 
  
  % calculate voxel coordinates in Lab system
  
  [xl,yl,zl]=gtTrSamToLab(x,y,z,o);
  
  n=[cosd(2*t);sind(2*t)*sind(e);sind(2*t)*cosd(e)];  % direction of the diffracted beam in Lab coordinates
  
  
  for nv=1:length(x)
	
	xi=xl(nv);
	yi=yl(nv);
	zi=zl(nv);
	
	% direct beam image
	if direct_beam
	  Imx=parameters.acq.rotx-yi;
	  Imy=parameters.acq.ydet/2+0.5-zi;

	  fracx=Imx-floor(Imx);
	  fracy=Imy-floor(Imy);

	  Ix=floor(Imx);
	  Iy=floor(Imy);

	  
	  proj(Iy,Ix,nr)=proj(Iy,Ix,nr)-(1-fracx)*(1-fracy);
	  proj(Iy,Ix+1,nr)=proj(Iy,Ix+1,nr)-fracx*(1-fracy);
	  proj(Iy+1,Ix,nr)=proj(Iy+1,Ix,nr)-(1-fracx)*fracy;
	  proj(Iy+1,Ix+1,nr)=proj(Iy+1,Ix+1,nr)-fracx*fracy;
	end % if
	%now solve  xi+ f*n(1)  = dist and calculate intersection point on the detector

	f=(dist-xi)/n(1);
	Pd=-(yi+f*n(2));
	Qd=zi+f*n(3);

	Imx=Pd+parameters.acq.rotx;
	Imy=parameters.acq.ydet/2+0.5-Qd;

	fracx=Imx-floor(Imx);
	fracy=Imy-floor(Imy);

	Ix=floor(Imx);
	Iy=floor(Imy);
	
	if Ix<0 || Iy<0 || Ix+1>size(proj,2) || Iy+1>size(proj,1)
	  %disp('projection out of detector');
	else
	  proj(Iy,Ix,nr)=proj(Iy,Ix,nr)+(1-fracx)*(1-fracy); %disp((1-fracx)*(1-fracy));
	  proj(Iy,Ix+1,nr)=proj(Iy,Ix+1,nr)+fracx*(1-fracy); %disp(fracx*(1-fracy));
	  proj(Iy+1,Ix,nr)=proj(Iy+1,Ix,nr)+(1-fracx)*fracy; %disp((1-fracx)*fracy);
	  proj(Iy+1,Ix+1,nr)=proj(Iy+1,Ix+1,nr)+fracx*fracy; %disp(fracx*fracy);
	  
	end % if
  end  % for nv
  

  proj(:,:,nr)=fliplr(proj(:,:,nr));  % because we look into the beam....
  
  if direct_beam
    extstack(:,:,nr)=gtCrop(proj(:,:,nr),parameters.acq.bb);
    %remove direct beam spot
    tmp=zeros(parameters.acq.bb(4),parameters.acq.bb(3));
    difspot=gtPlaceSubImage(tmp,proj(:,:,nr),parameters.acq.bb(1), parameters.acq.bb(2));
  else
	
     difspot=proj(:,:,nr);
  end
  
  a=regionprops(bwlabel(difspot>0)); 
 
  bb(nr,1)=ceil(a.BoundingBox(1));
  bb(nr,2)=ceil(a.BoundingBox(2));
  bb(nr,3)=a.BoundingBox(3);
  bb(nr,4)=a.BoundingBox(4);

  bb(nr,5)=round(a.Centroid(1));
  bb(nr,6)=round(a.Centroid(2));

  difstack{nr}=gtCrop(proj(:,:,nr),bb(nr,1:4));
  
  difspotid=grain.difspots(nr);
  [full,realbb]=gtGetSummedFullImage(difspotid,parameters);
  fulls(:,:,nr)=full;
  %realstack{nr}=gtCrop(fliplr(full),bb(1:4));
  
end % for nr

vsize=round(max(bb(:,4))*2);
hsize=round(max(bb(:,3))*2);

stack=zeros(vsize,hsize,length(index));

%% now write .cfg file for ASTRA reconstruction
projectionfilename='/users/ludwig/oblique/projections.dat';
outputfilename='/users/ludwig/oblique/output.dat';
niterations=20;


fid=fopen('/users/ludwig/oblique/test.cfg','w');
fprintf(fid,'%s\n',projectionfilename);
fprintf(fid,'%s\n',outputfilename);
fprintf(fid,'%d\n',niterations);
fprintf(fid,'%d %d %d \n',parameters.acq.bb(3),parameters.acq.bb(3),parameters.acq.bb(4));
fprintf(fid,'%d %d %d \n',length(index), hsize,vsize);

detucen0=parameters.geo.detucen0;
detvcen0=parameters.geo.detvcen0;
detdiru0=parameters.geo.detdiru0';
detdirv0=parameters.geo.detdirv0';
detpos0=(parameters.geo.detpos0/parameters.acq.pixelsize)';

detposcorner=detpos0-detucen0*detdiru0-detvcen0*detdirv0;

rotcomp = gtFedRotationMatrixComp(parameters.geo.rotdir0');


for i=1:length(index)
  voffset(i)=round((vsize-bb(index(i),4))/2);
  hoffset(i)=round((hsize-bb(index(i),3))/2);
  stack(:,:,i)=gtPlaceSubImage(difstack{index(i)},stack(:,:,i),hoffset(i)+1,voffset(i)+1);
 
  omega=grain.omega(index(i));
  eta=grain.eta(index(i));  
  theta=grain.theta(index(i));
  
  Rottens = gtFedRotationTensor(-omega,rotcomp);
  
  detpos00 = detposcorner + (bb(index(i),1)-hoffset(i)-1)*detdiru0	+ (bb(index(i),2)-voffset(i)-1)*detdirv0;
  
  detdiru = Rottens*detdiru0;
  detdirv = Rottens*detdirv0;
  detpos = Rottens*detpos00; 
  
  
  r=[cosd(2*theta);sind(2*theta)*sind(eta);sind(2*theta)*cosd(eta)];
  r=Rottens*r;
  
  fprintf(fid,'%f %f %f %f %f %f %f %f %f %f %f %f\n',r(1), r(2), r(3), detpos(1), detpos(2), detpos(3), detdiru(1), detdiru(2), detdiru(3), detdirv(1), detdirv(2), detdirv(3));
  
end  
  
fclose(fid);

stack=permute(stack,[2,3,1]);
volwrite(projectionfilename,stack,'float32');

end


