%
% function [samX,samY,samZ]=gtTrIndToSam(i,i,k,parameters)
%
% Given the Matlab Sample coordinates of a point, transforms them into LAB 
% coordinates according to omega (omega as where the diffraction event occured,
% thus normally positive between 0 and 360 degrees).
%
%   Sample system is right-handed and defined as: 
%     origin X = on the rotation axis, positive towards the camera
%     origin Y = on the rotation axis,positive towards the control room (at
%     omega = 0 == pmo -90 in Spec)
%     origin Z = floor(parameters.acq.ydet/2) in the middle of the central
%                pixel row of the image, positive upwards   
%
% INPUT  i = coloumn vector of X coordinates (vertical) in matlab array (arb. units)
%        j = coloumn vector of Y coordinates (horizontal) in matlab array (arb. units)
%        k = coloumn vector of Z coordinates (3rd dimension) in matlab array (arb. units)
%        
%
%
% OUTPUT samX = coloumn vector of X coordinates in the Sample system 
%        samY = coloumn vector of Y coordinates in the Sample system 
%        samZ = coloumn vector of Z coordinates in the Sample system 
%
%        e.g. [3234;3334;3434],[444;644;944],[545;824;632]
%


function [samX,samY,samZ]=gtTrIndToSam3D(i,j,k,parameters)
  % om = omega angle in degrees
  bb=parameters.acq.bb;
  
  samX=-bb(3)/2-0.5+i;
  samY=-bb(3)/2-0.5+j; 
  samZ= parameters.acq.ydet/2-bb(2)-bb(4)+k-1.5;
  
end
