%
% FUNCTION [lname, indout] = gtLastFileName(fname,w)
%
% Used before saving an output file. It gives a filename (.mat) ending with
% an integer after browsing the current folder or the given path.
% If w is 'existing', it outputs an exisitng filename with the largest 
% integer at the end. If w is 'new', the filename will have the largest+1 
% integer at the end.
%
% USAGE  gtLastFileName('myfiles','new') will give 'myfiles1.mat' or, if it
% already exists, then 'myfiles2.mat'.
%

function [lname, indout] = gtLastFileName(fname,w)

% Decompose path and fname
[pathstring, name] = fileparts(fname);

% Search for .mat files 
allfnames = dir([fname '*.mat']);

% If nothing found
if isempty(allfnames)
    if strcmp(w,'new')
        lname  = [fname '1.mat'];
        indout = 1;
        return
    else
        lname  = [];
        indout = []; 
        return
    end
end


% Continue if files exist

allnum = [];

% Loop through filenames; it may be a series with different numbers 
for i = 1:length(allfnames)
    
    % Get file number 
    num = str2double(allfnames(i).name(length(name)+1:end-4));
    
    if isnan(num)
        allnum(i) = 0;
    else
        allnum(i) = num;
    end
end

% Find the one with the highest number
[maxnum, maxind] = max(allnum);

% Return existing or new name
switch w
    case 'existing'
        lname  = fullfile(pathstring, allfnames(maxind).name);
        indout = maxnum;
        
    case 'new'
        lname  = sprintf('%s%d.mat',fname,maxnum+1);
        indout = maxnum + 1;
        
    otherwise
        lname  = [];
        indout = [];
        disp('Input option should be ''existing'' or ''new'' !')
end
	

end % of function
