function val = gtIndexAllGrainValues(grain, field1, field2, ind1, ind2)

% Returns a column vector containing the values with indices (ind1,ind2) in 
% grain.field1.field2 from all the grains in 'grain'. 
% 
% INPUT
%   grain  - all grain data (cell vector)
%   field1 - field 1 name (string)
%   field2 - field 2 name (string) or empty is not applicable
%   ind1   - index 1 of variable
%   ind2   - index 2 of variable or empty is not applicable
% 
% OUTPUT
%   val    - column vector; size(n,1) where n is the number of grains
%
% EXAMPLE
%   gtIndexAllGrainValues(grain,'nof_pairs',[],1,[])
%   gtIndexAllGrainValues(grain,'indST',[],3,3)
%   gtIndexAllGrainValues(grain,'stat','dangmean',1,[])
%


nof_grains = length(grain);

if ~exist('ind2','var')
    ind2 = [];
end


if isempty(ind2)
    twodim = false;  % parameter is a one dimensional vector
else
    twodim = true;   % parameter is a two dimensional array
end


% If there is no second field 
if isempty(field2)
    
    if twodim
        
        for ii = 1:nof_grains
            tmp = grain{ii}.(field1);
            val(ii,:) = tmp(ind1,ind2);
        end
        
    else
        
        for ii = 1:nof_grains
            tmp = grain{ii}.(field1);
            val(ii,:) = tmp(ind1);
        end
        
    end
    
% If there is a second field
else
    
    if twodim
        
        for ii = 1:nof_grains
            tmp = grain{ii}.(field1).(field2);
            val(ii,:) = tmp(ind1,ind2);
        end
        
    else
        
        for ii = 1:nof_grains
            tmp = grain{ii}.(field1).(field2);
            val(ii,:) = tmp(ind1);
        end
        
    end
    
end



end  % of function
