function [theoX, cgX2] = gtMathsCGSolveCellExample

    numComponents = 5e2;
    verbose = false;
    maxIters = 800;
    toll = 1e-8;

    fprintf('Generating A.. ')
    c = cos(linspace(1, 10, numComponents) / 20 * pi);
    A = toeplitz(c);
    fprintf('Done.\nConditioning number of A: %e\n\n', cond(A))

    H11 = {A, A};
    b = {rand(numComponents, 1), rand(numComponents, 1)};

    tic();
    theoX = cell(1, 2);
    for ii = 1:length(theoX)
        theoX{ii} = H11{ii} \ b{ii};
    end
    time_to_compute = toc();
    fprintf('\nMatlab''s Gauss-Pivoting: %f seconds\n\n', time_to_compute);

    tic();
    [cgX1, ~, numIters] = gtMathsCGSolveCell(H11, b, toll, maxIters, verbose, false);
    time_to_compute = toc();
    fprintf('\nMatlab''s implementation: %f seconds (NumIters: %d)\n\n', time_to_compute, numIters);
    tic();
    [cgX2, ~, numIters] = gtMathsCGSolveCell(H11, b, toll, maxIters, verbose, true);
    time_to_compute = toc();
    fprintf('\nNicola''s implementation: %f seconds (NumIters: %d)\n\n', time_to_compute, numIters);

%     tic();
%     cgX3 = cell(1, 2);
%     for ii = 1:length(cgX3)
%         [cgX3{ii}, ~, numIters(ii)] = cgsolve(H11{ii}, b{ii}, toll, maxIters, verbose);
%     end
%     time_to_compute = toc();
%     fprintf('\nL1magic''s implementation: %f seconds (NumIters: %d, %d)\n\n', time_to_compute, numIters);

    if (verbose)
        disp([theoX{1}, cgX1{1}, cgX2{1}])
    end

    fprintf('Max relative errors:');
    for ii = 1:length(theoX)
        fprintf(' (%e, %e)', max((theoX{ii} - cgX1{ii}) ./ theoX{ii}), ...
                max((theoX{ii} - cgX2{ii}) ./ theoX{ii}) );
    end
    fprintf('\n');
end
