function r = gtMathsEuler2Rod(euler)
% GTMATHSEULER2ROD  Convert Euler angles (in degrees) in Rodrigues vector r.
%                   These Euler angles follow Bunge convention (ZXZ).
%     -------------------------------------------------------------------------
%     r = gtMathsEuler2Rod([phi1, phi, phi2])
%
%     INPUT:
%       euler = <double>   row vector containing the 3 Euler angles (Bunge)
%
%     OUTPUT:
%       r     = <double>   Rodrigues vector r, 3 components row vector 
%
%     Version 001 15-06-2012 by YGuilhem

% Check size of r vector
if and(size(euler,1)==1, size(euler,2)==3)
    phi1 = deg2rad(euler(1));
    phi  = deg2rad(euler(2));
    phi2 = deg2rad(euler(3));
else
    Mexc = MException('Euler:wrong_vector_size',['Given vector size is not a 3 components row vector!']);
    throw(Mexc);
end

% Compute intermediate values a & b
a = (phi1 - phi2)/2;
b = (phi1 + phi2)/2;

% Compute Rodrigues vector components
r = [ tan(phi/2) * cos(a)/cos(b) ...
      tan(phi/2) * sin(a)/cos(b) ...
      tan(b)                    ];

end % end of function
