function g = gtMathsEuler2RotMat(euler)
% GTMATHSEULER2ROTMAT  Convert orientation matrix g into Euler angles.
%                      This follows Bunge convention (ZXZ).
%     -------------------------------------------------------------------------
%     g = gtMathsEuler2RotMat(euler)
%
%     INPUT:
%       euler = <double>  row vector containing the 3 Euler angles (Bunge)
%                         These angles should be given in degrees
%
%     OUTPUT:
%       g     = <double>  orientation matrix g 3x3 (see V. Randle's book)
%
%     Version 001 15-06-2012 by YGuilhem

% Check size of r vector
if and(size(euler,1)==1, size(euler,2)==3)
    phi1 = deg2rad(euler(1));
    phi  = deg2rad(euler(2));
    phi2 = deg2rad(euler(3));
else
    Mexc = MException('Euler:wrong_vector_size',['Given vector size is not a 3 components row vector!']);
    throw(Mexc);
end

% Compute intermediate values 
c1 = cos(phi1);
cg = cos(phi);
c2 = cos(phi2);
s1 = sin(phi1);
sg = sin(phi);
s2 = sin(phi2);

% Conpute g matrix components
g = [  c1*c2 - s1*cg*s2   s1*c2 + c1*cg*s2   sg*s2 ; ...
      -c1*s2 - s1*cg*c2   c1*cg*c2 - s1*s2   sg*c2 ; ...
       s1*sg             -c1*sg              cg         ];

end % end of function
