function g = gtMathsRod2RotMat(r)
% GTMATHSROD2ROTMAT  Convert Rodrigues vector r into orientation matrix.
%     -------------------------------------------------------------------------
%     g = gtMathsRod2RotMat(r)
%
%     INPUT:
%       r = <double>  Rodrigues vector r, 3 components, can be row or column 
%                     vector
%
%     OUTPUT:
%       g = <double>  
%
%     Version 001 15-06-2012 by YGuilhem

% Check size of r vector
if and(size(r,1)==3, size(r,2)==1)
    R = r;
elseif and(size(r,1)==1, size(r,2)==3)
    R = r';
else
    Mexc = MException('Rodrigues:wrong_vector_size',['Given vector size is neither 1x3, neither 3x1!']);
    throw(Mexc);
end

% Initialise the permutation tensor (do the 3rd as 1st, to allocate it all)
e(:, :, 3) = [ 0     1     0; ...
              -1     0     0; ...
               0     0     0];
e(:, :, 1) = [ 0     0     0; ...
               0     0     1; ...
               0    -1     0];
e(:, :, 2) = [ 0     0    -1; ...
               0     0     0; ...
               1     0     0];

% Saving partial computation
rSquareNorm = sum(r .^ 2);

% Initialise the orientation matrix
g = zeros(3, 3);
% Loop over the elements of the orientation matrix
for i = 1:3
    for j = 1:3
        g(i, j) = (1 - rSquareNorm) * (i == j) + 2 * r(i) * r(j);
        % Summing over the remaining component
        for k = 1:3
            g(i, j) = g(i, j) + 2 * r(k) * e(i, j, k);
        end
    end
end
g = g / (1 + rSquareNorm);

end % end of function
