function euler = gtMathsRotMat2Euler(g)
% GTMATHSROTMAT2EULER  Convert orientation matrix g into Euler angles.
%                      This follows Bunge convention (ZXZ).
%     -------------------------------------------------------------------------
%     euler = gtMathsRotMat2Euler(g)
%
%     INPUT:
%       g     = <double>  orientation matrix g 3x3 (see V. Randle's book)
%
%     OUTPUT:
%       euler = <double>  row vector containing the 3 Euler angles (Bunge)
%                         Output angles are in degrees and only positive
%
%     Version 001 15-06-2012 by YGuilhem

% Check size of g matrix
if size(g) ~= [3 3]
    Mexc = MException('RotMat:wrong_matrix_size',['Given matrix size is not 3x3!']);
    throw(Mexc);
end
 
if abs(g(3,3) - 1) < 1.e-9
    phi1 = atan2(g(1,2),g(1,1)); 
    phi  = 0;
    phi2 = phi1;
else
    phi1 = atan2(g(3,1),-g(3,2));
    phi  = acos(g(3,3));
    phi2 = atan2(g(1,3),g(2,3));
end

% Switch to degrees
euler = rad2deg([phi1 phi phi2]);

% Shift to positive angles range
euler = euler + 360.0 * (euler<0);

end % end of function
