function r = gtMathRotMat2Rod(g)
% GTMATHSROTMAT2EULER  Convert orientation matrix g into Rodrigues vector.
%     -------------------------------------------------------------------------
%     r = gtMathsRotMat2Rod(g)
%
%     INPUT:
%       g = <double>  orientation matrix g 3x3 (see V. Randle's book)
%
%     OUTPUT:
%       r = <double>  Rodrigues vector r, 3 components row vector 
%
%     Version 001 15-06-2012 by YGuilhem

% Check size of g matrix
if size(g) ~= [3 3]
    Mexc = MException('RotMat:wrong_matrix_size',['Given matrix size is not 3x3!']);
    throw(Mexc);
end

trace = g(1,1) + g(2,2) + g(3,3);

if abs(trace + 1) < 1.e-9
    r = zeros(1,3);
else
    r = [ g(2,3) - g(3,2) ...
          g(3,1) - g(1,3) ...
          g(1,2) - g(2,1) ];
    r = r/(trace + 1);
end

end % end of function
