function statsTable = gtOarGetStats(IDs, vars)
% GTOARGETSTATS  Gets Oar stats for the given job IDs
%     statsTable = gtOarGetStats(IDs, vars)
%     -------------------------------------
%
%     Sub-functions
%[sub]- mergeStructs

    % Creating the job query string
    jobsStrs = arrayfun(@(id){[' -j ' num2str(id)]}, IDs);
    jobsStr = ['! oarstat' jobsStrs{:} ' -f'];
    % Getting the output
    [~, output] = unix(jobsStr);

    % Now we chop the input:
    jobsBlocks = regexp(output, '\n\n', 'split');
    statsTable = cell(1, length(jobsBlocks) - 1);
    for ii = 1:length(IDs)
        statsTable{ii}.('Job_Id') = IDs(ii);
    end

    %%%%%%%%%%%%%%
    % check vars
    %%%%%%%%%%%%%%
    possible_vars = {...
        'assigned_hostnames', ...
        'assigned_resources', ...
        'command', ...
        'cpuset_name', ...
        'dependencies', ...
        'events', ...
        'exit_code', ...
        'initial_request', ...
        'job_array_id', ...
        'job_array_index', ...
        'jobType', ...
        'launchingDirectory', ...
        'message', ...
        'name', ...
        'owner', ...
        'project', ...
        'properties', ...
        'queue', ...
        'reservation', ...
        'resubmit_job_id', ...
        'scheduledStart', ...
        'startTime', ...
        'state', ...
        'stopTime', ...
        'submissionTime', ...
        'types', ...
        'walltime', ...
        'wanted_resources' };

    if (strcmpi(vars, 'all'))
        vars = possible_vars;
    else
        % Removing not allowed variables
        [newVars, acceptedIDs] = intersect(vars, possible_vars);

        if (length(newVars) ~= length(vars))
            fprintf('Removing not existing variables for OAR:\n   ')
            rejectedIDs = setdiff(1:length(vars), acceptedIDs);
            fprintf(' %s', vars{rejectedIDs});
            fprintf('\n');
        end

        vars = newVars;
    end

    % Now extract info from the output of 'oarstat'
    if (~isempty(statsTable))
        jobsBlocks = jobsBlocks(1:end-1);
        for ii = 1:length(vars)
            stats = regexp(jobsBlocks, [vars{ii} ' = (?<' vars{ii} '>.*?)\n'], 'names', 'once');
            statsTable = cellfun(@(x1, x2) gtMergeStructs(x1, x2, vars{ii}), statsTable, stats);
        end
    end
end % end of function 
