function oarStats = resubmitOar(error_ids)
%     oarStats = resubmitOar(error_ids)
%     ---------------------------------

if ~exist('error_ids','var') || isempty(error_ids)
    load('error_ids.mat');
end

oarStats = gtOarGetStats([error_ids.error; error_ids.terminated], {'all'});
for i=1:length(oarStats)
    oarStats{i}.properties = sfSplitProperties(oarStats{i}.properties);
    oarStats{i}.command    = sfSplitCommand(oarStats{i}.command);
    if ~strcmpi(oarStats{i}.exit_code,'0 (0,0,0)')
        disp(['oarStats.name: ' oarStats{i}.name])
        disp(['oarStats.Job_Id:    ' num2str(oarStats{i}.Job_Id)])
        print_structure(oarStats{i},'oarStats',false,true);
        check=inputwdefault('Do you want to resubmit this job? [y/n]','y');
        if strcmpi(check,'y')
            oarStats{i}.resubmit_job_id = oarStats{i}.Job_Id;
            disp(['Resubmitting job ' num2str(oarStats{i}.resubmit_job_id) '...'])
            OAR_make(oarStats{i}.name, oarStats{i}.command.first, oarStats{i}.command.last, 1, oarStats{i}.command.otherparameters, true, ...
                'walltime', oarStats{i}.walltime, ...
                'resubmit', oarStats{i}.resubmit_job_id)
        end
    end
end


end

function output = sfSplitCommand(command)

[~,rest] = strtok(command);
rest = strtrim(rest);
s = regexp(rest, '\s+', 'split');
first = str2double(s{2});
last = str2double(s{3});
s(1:3)=[];
s(2,:)={' '};
otherparameters = [s{1:end-1}];
output.first = first;
output.last = last;
output.otherparameters = otherparameters;

end

function output = sfSplitProperties(properties)

properties = strrep(properties,'''','');
properties = strrep(properties,'(','');
properties = strrep(properties,')','');
properties = strrep(properties,'AND','');
C = textscan(properties,'gpu = %s  mem>%d  desktop_computing = %s  private_node = %s  opsys = %s');
names = {'gpu','mem','desktop_computing','private_node','opsys'};
pippo = {[C{:}]};
output = cell2struct(pippo{:},names,2); 

end
