function submitOar(debug)
% FUNCTION SUBMITOAR  Submit jobs to OAR
%     SUBMITOAR(debug)
%       debug = flag to print or not comments

%   Version 003 08-11-2011 LNervo
%       Dealing better with logname
%
%   Version 002 20-09-2011 LNervo

out = GtConditionalOutput(debug);

set=[];
oarparameters=[];
disp(' ')
if exist('oarset.mat', 'file')
    fprintf('Loading oarset.mat...\n')
    load('oarset.mat');
else
    error('OAR:no_oarset', ...
          'The file oarset.mat does not exist. Please go in the directory where it is.')
end

if exist('oarparameters.mat', 'file')
    fprintf('Loading oarparameters.mat...\n')
    load('oarparameters.mat');
else
    error('OAR:no_oarparameters', ...
          'The file oarparameters.mat does not exist. Please go in the directory where it is.')
end

command=['oarsub -S ' set.oardirectives];

% going to the directory where to run the executable
disp(' ')
disp('Submitting the job(s)...')
[~, output_sub] = unix(command);
disp('...done!')

% Getting the job id array. The first value is the job_array_id.
inx = strfind(output_sub,'OAR_JOB');
output_sub = output_sub(inx:end);

% cell object array
array = regexp(output_sub,'[0-9]*','match');
array = sort(array);
array = unique(array);

fname = set.fname;

%% Save info of each job
vars = {'state', 'exit_code', 'submissionTime', 'startTime', 'stopTime', ...
        'owner'};
IDs = cellfun(@str2double, array);
oarStats = gtOarGetStats(IDs, vars);

for ii=1:length(array)
    job.jobId           = oarStats{ii}.Job_Id;
    job.state           = oarStats{ii}.state;
    job.exit_code       = oarStats{ii}.exit_code;
    job.submissionTime  = oarStats{ii}.submissionTime;
    job.startTime       = oarStats{ii}.startTime;
    job.stopTime        = oarStats{ii}.stopTime;
    oarparameters.(fname).(['array' array{1}]).job(ii) = job;
end

out.fprintf('\n\nSaving the oarparameters.mat file...');
save([set.launchdir filesep set.matparfile],'oarparameters','-append');
out.fprintf('done!\n');

log = set.logname;
set.logname = strrep(set.logname, '%jobid%', array{1});
movefile(log, set.logname);

save([set.launchdir filesep 'oarset.mat'], 'set');

disp(['OAR parameter file: ' set.launchdir filesep set.matparfile])
disp(' ')
disp('*** LOG FILES ***')
disp(set.logname)
% replace arrayid number
[~, ~] = unix(['sed -i -e s/' '%jobid%' '.log' '/' array{1} '.log' '/g ' set.logname]);
%
disp(strrep(log, '.log', '.out'))
disp(strrep(log, '.log', '.err'))

disp('arrayid: ')
disp(array(1))
disp('jobid: ')
disp(array)

% save arrayid into a text file
fid2 = fopen('oar.log', 'a+');
fprintf(fid2, '%s %s %s %s\n', oarStats{1}.owner, fname, array{1}, oarStats{1}.submissionTime);
fclose(fid2);

fid3 = fopen('arrays.txt', 'a+');
fprintf(fid3, '%s\n',fname);
for i=1:length(array)
    fprintf(fid3,'%s ', array{i});
end
fprintf(fid3,'\n');
fclose(fid3);

disp(' ')
disp('Check the jobs status with the command')
disp('    ! oarstat -j <jobid> -s')
disp('You can run this command to check the job status:')
disp(['    updateOar( ' array{1} ' )'])
disp(' ')
disp('You can easily look at error and output log files with:')
disp('    updateOar( <jobid> , ''err'' )')
disp('    updateOar( <jobid> , ''out'' )')
disp(' ')


end % end function
