function updateOar(queryname, action)
% UPDATEOAR
%     updateOar(queryname, action)
%     ----------------------------
%
%     Check OAR arrayjobs from OAR and update oarparameters.mat
%
%     INPUT:
%       queryname = arrayid <double> | function name <string>
%       action    = 'delete' | {'update'} | ('err','out','log','params','oar')
%                                           Use of logviewOar
%
%     Sub-functions:
%[sub]- deteleOarArray
%[sub]- updateArray
%


if (~exist('queryname', 'var') || isempty(queryname))
    queryname = 'gt';
end
if (~exist('action', 'var') || isempty(action))
    action = 'update';
end

oarparameters = [];
load('oarparameters.mat');

if ischar(queryname)
    lookfunc = true;
    funcname = queryname;
else
    lookfunc = false;
    arrayid = queryname;
end

if ~isempty(fieldnames(oarparameters))
    fnames = fieldnames(oarparameters);

    error_ids.terminated = [];
    error_ids.error      = [];

    if (lookfunc)
        %%%%%%%%%%%%%%%%%%%%%%%%%%
        % look for function name %
        %%%%%%%%%%%%%%%%%%%%%%%%%%
        if (~isempty(funcname))
            disp(['Looking for function named ' funcname ' ...'])
            match = strfind(fnames, funcname);
            jj = 0;
            % XXX - Laura, what is this doing?? please comment!! looks like
            % something very dirty. If you can avoid this kind of loops with
            % while and jumping indexes, please do it! It gets very difficult to
            % debug, in case of problems
            while (~isempty(match) && (jj < length(fnames)))
                jj = jj + 1;

                if isempty(match{jj})
                    fnames(jj) = [];
                    match(jj) = [];
                    jj = 0;
                end
            end
        end

        if (strcmpi(action, 'delete'))
            % loop over functions
            for jj = 1:length(fnames)
                disp(['Deleting function ' fnames{jj} '...']);
                arrayField = fieldnames(oarparameters.(fnames{jj}));

                questionStr = ['Are you sure to remove the function ' fnames{jj} ' from OAR and oarparameters.mat? [y/n]'];
                check = inputwdefault(questionStr, 'y');
                if strcmpi(check, 'y')
                    fprintf('Deleting jobs from OAR... ')
                    cellfun(@(array) deleteOarArray(array(6:end)), arrayField);
                    fprintf('Done.\nRemoving information about the jobs... ')
                    oarparameters = rmfield(oarparameters, fnames{jj});
                    save('oarparameters.mat', 'oarparameters', '-v7.3');
                    fprintf('Done.\n')
                end
            end
            save('oarparameters.mat','oarparameters', '-v7.3');

        elseif (strcmpi(action, 'update'))

            % loop over functions
            for jj = 1:length(fnames)
                arrays = fieldnames(oarparameters.(fnames{jj}));
                arrayName = fnames{jj};

                for kk = 1:length(arrays)
                    arrayField = arrays{kk};
                    [oarparameters, error_ids] = updateArray(oarparameters, arrayName, arrayField, error_ids);
                end % end for k
            end % end for j
            save('oarparameters.mat','oarparameters', '-v7.3');

        elseif any( cellfun(@(logarray) strcmpi(action, logarray), {'err','out','log','params','oar'}) )

            output = logviewOar(funcname, action);
            print_structure(output,'output',false,true);

        else
            % Fail :)
            error( 'OAR:wrong_argument', ...
                    'Action %s is not valid!', action)
        end

    else
        %%%%%%%%%%%%%%%%%%%%%%%%%
        % look for array number %
        %%%%%%%%%%%%%%%%%%%%%%%%%
        if any( cellfun(@(logarray) strcmpi(action, logarray), {'err','out','log','params','oar'}) )
            fprintf('Looking for job number "%d"...\n', arrayid)
            output = logviewOar(arrayid, action);
            print_structure(output, 'output', false, true);
        else
            % loop over functions
            fprintf('Looking for array number "%d"...\n', arrayid)

            for jj = 1:length(fnames)
                arrayName = fnames{jj};

                % search array id(s) for each function
                arrays = logviewOar(arrayName, [], false);
                % check if arrayid exists
                if ~isempty(find(arrays.(arrayName).arrays == arrayid, 1))
                    arrayField = sprintf('array%d', arrayid);
                    % Do we want to delete?
                    if strcmpi(action, 'delete')
                        disp(['Deleting array n. ' num2str(arrayid) '...']);
                        questionStr = ['Are you sure to remove array ' num2str(arrayid) ' from oarparameters.mat? [y/n]'];
                        check = inputwdefault(questionStr, 'y');
                        if strcmpi(check, 'y')
                            fprintf('Deleting jobs from OAR... ')
                            deleteOarArray(arrayid);
                            fprintf('Done.\nRemoving information about the jobs... ')

                            oarparameters.(arrayName) = rmfield(oarparameters.(arrayName), arrayField);
                            save('oarparameters.mat', 'oarparameters', '-v7.3');
                            fprintf('Done.\n')
                        end
                    % Do we want some update?
                    elseif strcmpi(action, 'update')
                        [oarparameters, error_ids] = updateArray(oarparameters, arrayName, arrayField, error_ids);
                    else
                        % Fail :)
                        error( 'OAR:wrong_argument', ...
                                'Action %s is not valid!', action)
                    end
                end % end if arrayid exists

            end % end for jj
        end
    end % end lookfunc

    save error_ids error_ids

end % end if

end % end of function

%%
% Sub-functions

function deleteOarArray(array)
% DELETEOARARRAY
% deleteOarArray(array)

    if ~ischar(array)
        array = num2str(array);
    end
    [~, message] = unix(['oardel --array ' array]);

    if strfind(message, '[ERROR]')
        error('OAR:error_in_deleting', message);
    end
end

function [oarparameters, error_ids] = updateArray(oarparameters, arrayName, arrayField, error_ids)
% UPDATEARRAY
% [oarparameters, error_ids] = updateArray(oarparameters, arrayName, arrayField, error_ids)

vars = {'state', 'exit_code', 'submissionTime', 'startTime', 'stopTime'};

% look for not empty jobs in the array
if isempty(oarparameters.(arrayName))
    oarparameters = rmfield(oarparameters, arrayName);
    save('oarparameters.mat', 'oarparameters', '-v7.3');
    disp(['Removed ' arrayName ' from oarparameters.mat'])
elseif isempty(oarparameters.(arrayName).(arrayField).job)
    oarparameters.(arrayName) = rmfield(oarparameters.(arrayName), arrayField);
    save('oarparameters.mat', 'oarparameters', '-v7.3');
    disp(['All the jobs from array ' arrayField(6:end) ' are terminated with exit_code ''0 (0,0,0)'''])
else
    jobs = oarparameters.(arrayName).(arrayField).job;
    njobs = length(jobs);
    oarStats = gtOarGetStats([jobs.jobId], vars);

    newJobs = struct(jobs(1:0));

    h_name = length(arrayName)+2;
    h_job  = length(num2str(jobs(1).jobId))+2;
    h_other = length(datestr(now(),'yyyy-mm-dd HH:MM:SS'))+2;

    %%%%%%%%%%%%%%%%%%%%%%%
    % loop through jobs
    for m = 1 : njobs
        fprintf('%*s %*d ', h_name, arrayName, h_job, jobs(m).jobId)
        for l = 1:length(vars)
            jobs(m).(vars{l}) = oarStats{m}.(vars{l});
            fprintf('%*s ', h_other, jobs(m).(vars{l}))
        end
        fprintf('\n')

        state   = jobs(m).('state');
        code    = jobs(m).('exit_code');
        arrayid = jobs(1).('jobId');
        jobid   = jobs(m).('jobId');

        % Remove terminated good jobs
        if strcmpi(state, 'Terminated') && strcmpi(code, '0 (0,0,0)')
            disp(['Removed terminated job ' num2str(jobid) ' from array ' num2str(arrayid) '...'])
        else
            newJobs(end+1) = jobs(m); %#ok<AGROW>
        end

        if ~strcmpi(code, '0 (0,0,0)') && strcmpi(state, 'Terminated')
            error_ids.terminated = [error_ids.terminated; jobid];
        elseif strcmpi(state, 'Error')
            error_ids.error = [error_ids.error; jobid];
        end
    end

    oarparameters.(arrayName).(arrayField).job = newJobs;
    save('oarparameters.mat', 'oarparameters', '-v7.3');
end % end if
end % end subfunction updateArray
